OC.L10N.register(
    "spreed",
    {
    "a conversation" : "razgovor",
    "(Duration %s)" : "(Trajanje %s)",
    "You attended a call with {user1}" : "Sudjelovali ste u pozivu s {user1}",
    "_%n guest_::_%n guests_" : ["%n gost","%n gostiju","%n gostiju"],
    "You attended a call with {user1} and {user2}" : "Sudjelovali ste u pozivu s {user1} i {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Sudjelovali ste u pozivu s {user1}, {user2} i {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Sudjelovali ste u pozivu s {user1}, {user2}, {user3} i {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Sudjelovali ste u pozivu s {user1}, {user2}, {user3}, {user4} i {user5}",
    "_%n other_::_%n others_" : ["još %n","još %n","još %n"],
    "{actor} invited you to {call}" : "{actor} vas je pozvao u {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Pozvani ste u <strong>razgovor</strong> ili ste sudjelovali u <strong>pozivu</strong>",
    "Other activities" : "Druge aktivnosti",
    "Talk" : "Razgovor",
    "Guest" : "Gost",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Dobro došli u Nextcloud Talk!\nU ovom razgovoru bit ćete obaviješteni o novim značajkama dostupnima u Nextcloud Talku.",
    "## New in Talk %s" : "## Novo u Talku %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Sada možete upotrebljavati Microsoft Edge i Safari za sudjelovanje u glasovnim i videopozivima",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Razgovori jedan na jedan sada su zaštićeni i više se ne mogu slučajno pretvoriti u grupne razgovore. Također se razgovor više ne briše automatski ako jedan od sudionika napusti razgovor. Razgovor se briše s poslužitelja samo ako ga napuste oba sudionika",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Sada možete obavijestiti sve sudionike slanjem „@all” u prozor za razmjenu poruka",
    "- With the \"arrow-up\" key you can repost your last message" : "- Možete ponovno objaviti posljednju poruku s pomoću tipke sa strelicom prema gore",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk sada ima naredbe, unesite „/help” u prozor za razmjenu poruka kako biste vidjeli naredbe koje je konfigurirao vaš administrator",
    "- With projects you can create quick links between conversations, files and other items" : "- Koristite se projektima za stvaranje brzih poveznica između razgovora, datoteka i drugih stavki",
    "- You can now mention guests in the chat" : "- Sada možete navesti goste u prozoru za razmjenu poruka",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Razgovori sada mogu imati predvorje. To omogućuje moderatorima da se priključe razmjeni poruka i pozivima kako bi pripremili sastanak dok korisnici i gosti čekaju",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Sada možete izravno odgovarati na poruke kako biste drugim korisnicima pružili dodatni kontekst za svoje poruke",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Značajka traženja razgovora i sudionika sada će filtrirati vaše postojeće razgovore radi lakšeg traženja prethodnih razgovora",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Sada možete dodati prilagođene grupe korisnika u razgovore ako je instalirana aplikacija za upravljanje krugovima",
    "- Check out the new grid and call view" : "- Isprobajte nove prikaze rešetke i poziva",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Sada možete otpremati i povlačiti datoteke izravno sa svog uređaja u prozor za razmjenu poruka",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Dijeljene datoteke sada možete otvarati izravno u prikazu za razmjenu poruka s pomoću odgovarajućih preglednika",
    "- You can now search for chats and messages in the unified search in the top bar" : "- sada možete pretraživati poruke putem objedinjenog pretraživača u gornjoj traci",
    "- Spice up your messages with emojis from the emoji picker" : "- začinite svoje poruke emojijima iz alata za odabir emojija",
    "- You can now change your camera and microphone while being in a call" : "- sada možete promijeniti kameru i mikrofon tijekom poziva",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Predstavite svoje razgovore unosom opisa i otvorite ih kako bi ih prijavljeni korisnici mogli pronaći i pridružiti se",
    "- See a read status and send failed messages again" : "- Prikaži status čitanja i ponovno pošalji neuspješne poruke",
    "- Raise your hand in a call with the R key" : "- Podignite ruku u pozivu pritiskom gumba R",
    "- Join the same conversation and call from multiple devices" : "- Pridružite se istom razgovoru i zovite s više uređaja",
    "- Send voice messages, share your location or contact details" : "- Šaljite glasovne poruke, dijelite svoju lokaciju ili podatke za kontakt",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Dodajte grupe u razgovor i novi će se članovi grupe automatski dodati kao sudionici",
    "- A preview of your audio and video is shown before joining a call" : "- Prije pridruživanja pozivu prikazuje se pregled vašeg zvuka i videa",
    "- You can now blur your background in the newly designed call view" : "- Sada možete zamutiti pozadinu u novo dizajniranom prikazu poziva",
    "- Moderators can now assign general and individual permissions to participants" : "- Moderatori sada mogu dodijeliti opća i pojedinačna dopuštenja sudionicima",
    "- You can now react to chat messages" : "- Sada možete reagirati na poruke u chatu",
    "- In the sidebar you can now find an overview of the latest shared items" : "- U bočnoj traci sada možete pronaći pregled najnovijih dijeljenih stavki",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Upotrijebite anketu za prikupljanje mišljenja drugih ili dogovor oko datuma",
    "- Configure an expiration time for chat messages" : "- Postavite vrijeme isteka za poruke u chatu",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Pokrenite pozive bez obavještavanja drugih u velikim razgovorima. Pojedinačne obavijesti o pozivu možete poslati nakon što poziv započne.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Šaljite poruke u chatu bez obavještavanja primatelja ako nije hitno",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Emojiji se sada mogu automatski dovršavati upisivanjem \":\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Povežite razne stavke pomoću novog pametnog birača upisivanjem \"/\"",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Moderatori sada mogu stvarati sobe za odvajanje (zahtijeva visokoučinkoviti pozadinski sustav)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Pozivi se sada mogu snimati (zahtijeva visokoučinkoviti pozadinski sustav)",
    "- Conversations can now have an avatar or emoji as icon" : "- Razgovori sada mogu imati avatar ili emoji kao ikonu",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Virtualne pozadine sada su dostupne uz zamućenu pozadinu u videopozivima",
    "- Reactions are now available during calls" : "- Reakcije su sada dostupne tijekom poziva",
    "- Typing indicators show which users are currently typing a message" : "- Indikatori tipkanja prikazuju koji korisnici trenutačno pišu poruku",
    "- Groups can now be mentioned in chats" : "- Grupe se sada mogu spominjati u chatovima",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Snimke poziva automatski se pretvaraju u tekst ako je registrirana aplikacija za pružatelja pretvatanja",
    "- Chat messages can be translated if a translation provider app is registered" : "- Poruke u chatu mogu se prevoditi ako je registrirana aplikacija za pružatelja prijevoda",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** se sada može koristiti u porukama _chata_",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Webhookovi su sada dostupni za implementaciju botova. Više informacija potražite u dokumentaciji https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Postavite podsjetnik na poruku u chatu kako biste kasnije ponovno dobili obavijest",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Upotrijebite razgovor **Bilješka za sebe** za bilješke i dijeljenje informacija između svojih uređaja",
    "- Captions allow to send a message with a file at the same time" : "- Natpisi omogućuju slanje poruke i datoteke istodobno",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Video govornika sada je vidljiv tijekom dijeljenja zaslona, a reakcije u pozivu su animirane",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Poruke sada mogu uređivati prijavljeni autori i moderatori tijekom 6 sati",
    "- Unsent message drafts are now saved in your browser" : "- Nacrti neposlanih poruka sada se spremaju u vašem pregledniku",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Tekstualni chat sada se može voditi udruženo s drugim Talk poslužiteljima",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Moderatori sada mogu zabraniti račune i goste kako bi spriječili ponovno pridruživanje razgovoru",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Nadolazeći pozivi iz povezanih događaja u kalendaru i zamjene tijekom odsutnosti sada su prikazani u razgovorima",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Pozivi se sada mogu obavljati udruženo s drugim Talk poslužiteljima (zahtijeva visokoučinkoviti pozadinski sustav)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Predstavljamo Nextcloud Talk desktop klijent za Windows, macOS i Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Sažmite snimke poziva i nepročitane poruke u chatovima uz Nextcloud Assistant",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Poboljšani sastanci uz prepoznavanje gostiju pozvanih putem e‑pošte, uvoz popisa sudionika, skice za ankete i preuzimanje popisa sudionika poziva",
    "- Archive conversations to stay focused" : "- Arhivirajte razgovore kako biste ostali fokusirani",
    "- Schedule a meeting into your calendar from within a conversation" : "- Zakažite sastanak u svoj kalendar izravno iz razgovora",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Pretražujte poruke trenutnog razgovora izravno u desnoj bočnoj traci",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Na prvi pogled vidite više razgovora uz novi kompaktni popis (omogućite u postavkama Talka)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Razgovori o sastancima sada sinkroniziraju naslov i opis iz kalendara te su skriveni filtrom pretraživanja dok se ne približe početku",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Označite razgovore kao osjetljive u postavkama obavijesti kako biste sakrili sadržaj poruka na popisu razgovora i u obavijestima",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Kako biste primali push obavijesti tijekom opcije „Ne ometaj”, označite razgovore kao važne",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Dodajte druge sudionike u poziv jedan‑na‑jedan i u hodu stvorite novi grupni poziv",
    "- Use threads to keep your chat and discussions organized" : "- Koristite niti kako bi chat i rasprave bile organizirane",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Pretvaranje snimke u tekst uživo sada je dostupna tijekom poziva (zahtijeva ExApp za pretvanje uživo i visokoučinkoviti pozadinski sustav)",
    "- Moderators can now pin messages so they are kept at the top" : "- Moderatori sada mogu prikvačiti poruke kako bi ostale na vrhu",
    "- Schedule a message to send it at a later time" : "- Zakažite slanje poruke u kasnije vrijeme",
    "_All %n participant_::_All %n participants_" : ["Svi sudionici (%n)","Svi sudionici (%n)","Svi sudionici (%n)"],
    "Talk updates ✅" : "Ažuriranja aplikacije Talk ✅",
    "Reaction deleted by author" : "Reakciju je obrisao autor",
    "{actor} created the conversation" : "{actor} je stvorio razgovor",
    "You created the conversation" : "Stvorili ste razgovor",
    "System created the conversation" : "Sustav je stvorio razgovor",
    "An administrator created the conversation" : "Administrator je stvorio razgovor",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} je preimenovao razgovor iz „%1$s” u „%2$s”",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Preimenovali ste razgovor iz „%1$s” u „%2$s”",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Administrator je preimenovao razgovor iz „%1$s” u „%2$s”",
    "{actor} set the description" : "{actor} je postavio opis",
    "You set the description" : "Vi ste postavili opis",
    "An administrator set the description" : "Administrator je postavio opis",
    "{actor} removed the description" : "{actor} je uklonio opis",
    "You removed the description" : "Vi ste uklonili opis",
    "An administrator removed the description" : "Administrator je uklonio opis",
    "You started a silent call" : "Pokrenuli ste tihi poziv",
    "Outgoing silent call" : "Odlazni tihi poziv",
    "{actor} started a silent call" : "{actor} je pokrenuo tihi poziv",
    "Incoming silent call" : "Dolazni tihi poziv",
    "You started a call" : "Pokrenuli ste poziv",
    "Outgoing call" : "Odlazni poziv",
    "{actor} started a call" : "{actor} je pokrenuo poziv",
    "Incoming call" : "Dolazni poziv",
    "{actor} joined the call" : "{actor} se pridružio pozivu",
    "You joined the call" : "Pridružili ste se pozivu",
    "{actor} left the call" : "{actor} je napustio poziv",
    "You left the call" : "Napustili ste poziv",
    "{actor} unlocked the conversation" : "{actor} je otključao razgovor",
    "You unlocked the conversation" : "Otključali ste razgovor",
    "An administrator unlocked the conversation" : "Administrator je otključao razgovor",
    "{actor} locked the conversation" : "{actor} je zaključao razgovor",
    "You locked the conversation" : "Zaključali ste razgovor",
    "An administrator locked the conversation" : "Administrator je zaključao razgovor",
    "{actor} limited the conversation to the current participants" : "{actor} je ograničio razgovor na trenutne sudionike",
    "You limited the conversation to the current participants" : "Ograničili ste razgovor na trenutne sudionike",
    "An administrator limited the conversation to the current participants" : "Administrator je ograničio razgovor na trenutne sudionike",
    "{actor} opened the conversation to registered users" : "{actor} je otvorio razgovor registriranim korisnicima",
    "You opened the conversation to registered users" : "Otvorili ste razgovor registriranim korisnicima",
    "An administrator opened the conversation to registered users" : "Administrator je otvorio razgovor registriranim korisnicima",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} je otvorio razgovor za registrirane korisnike i korisnike stvorene aplikacijom Gosti",
    "You opened the conversation to registered users and users created with the Guests app" : "Otvorili ste razgovor za registrirane korisnike i korisnike stvorene aplikacijom Gosti",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Administrator je otvorio razgovor za registrirane korisnike i korisnike stvorene aplikacijom Gosti",
    "The conversation is now open to everyone" : "Razgovor je sada otvoren svima",
    "{actor} opened the conversation to everyone" : "{actor} je otvorio razgovor svima",
    "You opened the conversation to everyone" : "Vi ste otvorili razgovor svima",
    "{actor} restricted the conversation to moderators" : "{actor} je ograničio razgovor samo na moderatore",
    "You restricted the conversation to moderators" : "Vi ste ograničili razgovor samo na moderatore",
    "{actor} started breakout rooms" : "{actor} je pokrenuo sobe za odvajanje",
    "You started breakout rooms" : "Pokrenuli ste sobe za odvajanje",
    "{actor} stopped breakout rooms" : "{actor} je zaustavio sobe za odvajanje",
    "You stopped breakout rooms" : "Zaustavili ste sobe za odvajanje",
    "{actor} allowed guests" : "{actor} je dopustio pristup gostima",
    "You allowed guests" : "Dopustili ste pristup gostima",
    "An administrator allowed guests" : "Administrator je dopustio pristup gostima",
    "{actor} disallowed guests" : "{actor} je zabranio pristup gostima",
    "You disallowed guests" : "Zabranili ste pristup gostima",
    "An administrator disallowed guests" : "Administrator je zabranio pristup gostima",
    "{actor} set a password" : "{actor} je postavio zaporku",
    "You set a password" : "Postavili ste zaporku",
    "An administrator set a password" : "Administrator je postavio zaporku",
    "{actor} removed the password" : "{actor} je uklonio zaporku",
    "You removed the password" : "Uklonili ste zaporku",
    "An administrator removed the password" : "Administrator je uklonio zaporku",
    "{actor} added {user}" : "{actor} je dodao {user}",
    "You joined the conversation" : "Pridružili ste se razgovoru",
    "{actor} joined the conversation" : "{actor} se pridružio razgovoru",
    "You added {user}" : "Dodali ste {user}",
    "{actor} added you" : "Dodao vas je {actor}",
    "An administrator added you" : "Administrator vas je dodao",
    "An administrator added {user}" : "Administrator je dodao {user}",
    "You left the conversation" : "Napustili ste razgovor",
    "{actor} left the conversation" : "{actor} je napustio razgovor",
    "{actor} removed {user}" : "{actor} je uklonio {user}",
    "You removed {user}" : "Uklonili ste {user}",
    "{actor} removed you" : "{actor} vas je uklonio",
    "An administrator removed you" : "Administrator vas je uklonio",
    "An administrator removed {user}" : "Administrator je uklonio {user}",
    "{actor} invited {federated_user}" : "{actor} je pozvao {federated_user}",
    "You invited {federated_user}" : "Pozvali ste {federated_user}",
    "You accepted the invitation" : "Prihvatili ste poziv",
    "{actor} invited you" : "{actor} vas je pozvao",
    "An administrator invited you" : "Administrator vas je pozvao",
    "An administrator invited {federated_user}" : "Administrator je pozvao {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} je prihvatio poziv",
    "{actor} removed {federated_user}" : "{actor} je uklonio {federated_user}",
    "You removed {federated_user}" : "Uklonili ste {federated_user}",
    "You declined the invitation" : "Odbili ste poziv",
    "An administrator removed {federated_user}" : "Administrator je uklonio {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} je odbio poziv",
    "{actor} added group {group}" : "{actor} je dodao grupu {group}",
    "You added group {group}" : "Dodali ste grupu {group}",
    "An administrator added group {group}" : "Administrator je dodao grupu {group}",
    "{actor} removed group {group}" : "{actor} je uklonio grupu {group}",
    "You removed group {group}" : "Uklonili ste grupu {group}",
    "An administrator removed group {group}" : "Administrator je uklonio grupu {group}",
    "{actor} added team {circle}" : "{actor} je dodao tim {circle}",
    "You added team {circle}" : "Dodali ste tim {circle}",
    "An administrator added team {circle}" : "Administrator je dodao tim {circle}",
    "{actor} removed team {circle}" : "{actor} je uklonio tim {circle}",
    "You removed team {circle}" : "Uklonili ste tim {circle}",
    "An administrator removed team {circle}" : "Administrator je uklonio tim {circle}",
    "{actor} added {phone}" : "{actor} je dodao {phone}",
    "You added {phone}" : "Dodali ste {phone}",
    "An administrator added {phone}" : "Administrator je dodao {phone}",
    "{actor} removed {phone}" : "{actor} je uklonio {phone}",
    "You removed {phone}" : "Uklonili ste {phone}",
    "An administrator removed {phone}" : "Administrator je uklonio {phone}",
    "{actor} promoted {user} to moderator" : "{actor} je unaprijedio {user} u moderatora",
    "You promoted {user} to moderator" : "Unaprijedili ste {user} u moderatora",
    "{actor} promoted you to moderator" : "{actor} vas je unaprijedio u moderatora",
    "An administrator promoted you to moderator" : "Administrator vas je unaprijedio u moderatora",
    "An administrator promoted {user} to moderator" : "Administrator je unaprijedio {user} u moderatora",
    "{actor} demoted {user} from moderator" : "{actor} je oduzeo status moderatora {korisnik}",
    "You demoted {user} from moderator" : "Oduzeli ste status moderatora {user}",
    "{actor} demoted you from moderator" : "{actor} vam je oduzeo status moderatora",
    "An administrator demoted you from moderator" : "Administrator vam je oduzeo status moderatora",
    "An administrator demoted {user} from moderator" : "Administrator je oduzeo {user} status moderatora",
    "{actor} shared a file which is no longer available" : "{actor} dijeli datoteku koja više nije dostupna",
    "You shared a file which is no longer available" : "Dijelite datoteku koja više nije dostupna",
    "File shares are currently not supported in federated conversations" : "Dijeljenja datoteka trenutačno nisu podržana u udruženim razgovorima",
    "The shared location is malformed" : "Dijeljena lokacija je pogrešno oblikovana",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} je postavio Matterbridge kako bi sinkronizirao ovaj razgovor s drugim razmjenama poruka",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Postavili ste Matterbridge kako biste sinkronizirali ovaj razgovor s drugim razmjenama poruka",
    "{actor} created thread {title}" : "{actor} je stvorio nit {title}",
    "You created thread {title}" : "Stvorili ste nit {title}",
    "{actor} renamed thread {title}" : "{actor} je preimenovao nit {title}",
    "You renamed thread {title}" : "Preimenovali ste nit {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} je ažurirao konfiguraciju Matterbridgea",
    "You updated the Matterbridge configuration" : "Ažurirali ste konfiguraciju Matterbridgea",
    "{actor} removed the Matterbridge configuration" : "{actor} je uklonio konfiguraciju Matterbridgea",
    "You removed the Matterbridge configuration" : "Uklonili ste konfiguraciju Matterbridgea",
    "{actor} started Matterbridge" : "{actor} je pokrenuo Matterbridge",
    "You started Matterbridge" : "Vi ste pokrenuli Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} je zaustavio Matterbridge",
    "You stopped Matterbridge" : "Vi ste zaustavili Matterbridge",
    "{actor} deleted a message" : "{actor} je izbrisao poruku",
    "You deleted a message" : "Izbrisali ste poruku",
    "{actor} edited a message" : "{actor} je uredio poruku",
    "You edited a message" : "Uredili ste poruku",
    "{actor} pinned a message" : "{actor} je prikvačio poruku",
    "You pinned a message" : "Prikvačili ste poruku",
    "{actor} unpinned a message" : "{actor} je otkvačio poruku",
    "Message was automatically unpinned" : "Poruka je automatski otkvačena",
    "You unpinned a message" : "Otkačili ste poruku",
    "{actor} deleted a reaction" : "{actor} je obrisao reakciju",
    "You deleted a reaction" : "Obrisali ste reakciju",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Postavili ste istjecanje poruka na %n tjedan","Postavili ste istjecanje poruka na %n tjedna","Postavili ste istjecanje poruka na %n tjedana"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Postavili ste istjecanje poruka na %n dan","Postavili ste istjecanje poruka na %n dana","Postavili ste istjecanje poruka na %n dana"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Postavili ste istjecanje poruka na %n sat","Postavili ste istjecanje poruka na %n sata","Postavili ste istjecanje poruka na %n sati"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Postavili ste istjecanje poruka na %n minutu","Postavili ste istjecanje poruka na %n minute","Postavili ste istjecanje poruka na %n minuta"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} je postavio istjecanje poruka na %n tjedan","{actor} je postavio istjecanje poruka na %n tjedna","{actor} je postavio istjecanje poruka na %n tjedana"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} je postavio istjecanje poruka na %n dan","{actor} je postavio istjecanje poruka na %n dana","{actor} je postavio istjecanje poruka na %n dana"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} je postavio istjecanje poruka na %n sat","{actor} je postavio istjecanje poruka na %n sata","{actor} je postavio istjecanje poruka na %n sati"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} je postavio istjecanje poruka na %n minutu","{actor} je postavio istjecanje poruka na %n minute","{actor} je postavio istjecanje poruka na %n minuta"],
    "{actor} disabled message expiration" : "{actor} je onemogućio istjecanje poruka",
    "You disabled message expiration" : "Onemogućili ste istjecanje poruka",
    "{actor} cleared the history of the conversation" : "{actor} je obrisao povijest razgovora",
    "You cleared the history of the conversation" : "Obrisali ste povijest razgovora",
    "{actor} set the conversation picture" : "{actor} je postavio sliku razgovora",
    "You set the conversation picture" : "Postavili ste sliku razgovora",
    "{actor} removed the conversation picture" : "{actor} je uklonio sliku razgovora",
    "You removed the conversation picture" : "Uklonili ste sliku razgovora",
    "{actor} ended the poll {poll}" : "{actor} je završio anketu {poll}",
    "You ended the poll {poll}" : "Završili ste anketu {poll}",
    "{actor} started the video recording" : "{actor} je pokrenuo snimanje videa",
    "You started the video recording" : "Pokrenuli ste snimanje videa",
    "{actor} stopped the video recording" : "{actor} je zaustavio snimanje videa",
    "You stopped the video recording" : "Zaustavili ste snimanje videa",
    "{actor} started the audio recording" : "{actor} je pokrenuo snimanje zvuka",
    "You started the audio recording" : "Pokrenuli ste snimanje zvuka",
    "{actor} stopped the audio recording" : "{actor} je zaustavio snimanje zvuka",
    "You stopped the audio recording" : "Zaustavili ste snimanje zvuka",
    "The recording failed" : "Snimanje nije uspjelo",
    "Someone voted on the poll {poll}" : "Netko je glasao u anketi {poll}",
    "Message deleted by author" : "Autor je izbrisao poruku",
    "Message deleted by {actor}" : "Poruku je izbrisao {actor}",
    "Message deleted by you" : "Poruku ste vi izbrisali",
    "Deleted user" : "Izbrisan korisnik",
    "Unknown number" : "Nepoznati broj",
    "Administration" : "Administracija",
    "System" : "Sustav",
    "%s (guest)" : "%s (gost)",
    "Missed call" : "Propušten poziv",
    "Unanswered call" : "Neodgovoreni poziv",
    "Call ended (Duration {duration})" : "Poziv je završen (trajanje {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Poziv je završen jer je dosegnuto maksimalno trajanje poziva (trajanje {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} je završio poziv (trajanje {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Poziv s %n gostom je završen jer je dosegnuto maksimalno trajanje poziva (trajanje {duration})","Poziv s %n gosta je završen jer je dosegnuto maksimalno trajanje poziva (trajanje {duration})","Poziv s %n gostiju je završen jer je dosegnuto maksimalno trajanje poziva (trajanje {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Poziv s %n gostom je završen (trajanje {duration})","Poziv s %n gosta je završen (trajanje {duration})","Poziv s %n gostiju je završen (trajanje {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} je završio poziv s %n gostom (Trajanje {duration})","{actor} je završio poziv s %n gosta (Trajanje {duration})","{actor} je završio poziv s %n gostiju (Trajanje {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Poziv s {user1} je završen jer je dosegnuto maksimalno trajanje poziva (trajanje {duration})",
    "Call with {user1} ended (Duration {duration})" : "Poziv s {user1} je završen (trajanje {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} je završio poziv s {user1} (Trajanje {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Poziv s {user1} i {user2} je završen jer je dosegnuto maksimalno trajanje poziva (trajanje {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Poziv s {user1} i {user2} je završen (trajanje {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} je završio poziv s {user1} i {user2} (Trajanje {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Poziv s {user1}, {user2} i {user3} je završen jer je dosegnuto maksimalno trajanje poziva (trajanje {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Poziv s {user1}, {user2} i {user3} je završen (trajanje {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} je završio poziv s {user1}, {user2} i {user3} (Trajanje {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Poziv s {user1}, {user2}, {user3} i {user4} je završen jer je dosegnuto maksimalno trajanje poziva (trajanje {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Poziv s {user1}, {user2}, {user3} i {user4} je završen (trajanje {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} je završio poziv s {user1}, {user2}, {user3} i {user4} (Trajanje {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Poziv s {user1}, {user2}, {user3}, {user4} i {user5} je završen jer je dosegnuto maksimalno trajanje poziva (trajanje {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Poziv s {user1}, {user2}, {user3}, {user4} i {user5} je završen (trajanje {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} je završio poziv s {user1}, {user2}, {user3}, {user4} i {user5} (Trajanje {duration})",
    "Message of {user} in {conversation}" : "Poruka korisnika {user} u {conversation}",
    "Message of {user}" : "Poruka korisnika {user}",
    "Message of a deleted user in {conversation}" : "Poruka obrisanog korisnika u {conversation}",
    "Talk conversations" : "Razgovori u alatu Talk",
    "Call %s" : "Poziv %s",
    "An error occurred. Please contact your administrator." : "Došlo je do pogreške. Obratite se administratoru.",
    "Storage quota exceeded" : "Kvote je premašena",
    "File not found" : "Datoteka nije pronađena",
    "File is not shared, or shared but not with the user" : "Datoteka se ne dijeli ili se ne dijeli samo s korisnikom",
    "No account available to delete." : "Nema računa za brisanje.",
    "Poll" : "Anketa",
    "Password needs to be set" : "Potrebno je postaviti lozinku",
    "Uploading the file failed" : "Prijenos datoteke nije uspio",
    "No image file provided" : "Nijedna slika nije dobavljena",
    "File is too big" : "Datoteka je prevelika",
    "Invalid file provided" : "Nevažeća datoteka",
    "Invalid image" : "Slika neispravna",
    "Unknown filetype" : "Vrsta datoteke nepoznata",
    "Talk mentions" : "Spominjanja u alatu Talk",
    "More conversations" : "Više razgovora",
    "Say hi to your friends and colleagues!" : "Pozdravi svoje prijatelje i kolege!",
    "No unread mentions" : "Nema nepročitanih spominjanja",
    "Call in progress" : "Poziv u tijeku",
    "You were mentioned" : "Spomenuti ste",
    "Write to conversation" : "Napiši u razgovor",
    "Writes event information into a conversation of your choice" : "Upisuje informacije o događaju u željeni razgovor",
    "Missing email field in header line" : "Nedostaje polje e-pošte u retku zaglavlja",
    "Following lines are invalid: %s" : "Sljedeći redci nisu valjani: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s vas je pozvao u razgovor \"%2$s\".",
    "You were invited to conversation \"%s\"." : "Pozvani ste u razgovor \"%s\".",
    "Conversation invitation" : "Poziv u razgovor",
    "Scheduled time" : "Zakazano vrijeme",
    "Description" : "Opis",
    "You can also dial-in via phone with the following details" : "Također se možete povezati putem telefona sa sljedećim podacima",
    "Dial-in information" : "Podaci za povezivanje putem telefona",
    "Meeting ID" : "ID sastanka",
    "Your PIN" : "Vaš PIN",
    "Click the button below to join the lobby now." : "Kliknite gumb ispod da se sada pridružite predvorju.",
    "Click the link below to join the lobby now." : "Kliknite poveznicu ispod da se sada pridružite predvorju.",
    "Join lobby for \"%s\"" : "Pridružite se predvorju za \"%s\"",
    "Click the button below to join the conversation now." : "Kliknite gumb ispod da se sada pridružite razgovoru.",
    "Click the link below to join the conversation now." : "Kliknite poveznicu ispod da se sada pridružite razgovoru.",
    "Join \"%s\"" : "Pridružite se \"%s\"",
    "Meeting" : "Sastanak",
    "Password request: %s" : "Zaporka: %s",
    "Private conversation" : "Privatni razgovor",
    "Deleted user (%s)" : "Izbrisan korisnik (%s)",
    "Failed to upload call recording" : "Prijenos snimke poziva nije uspio",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Poslužitelj za snimanje nije uspio prenijeti snimku poziva {call}. Obratite se administratoru.",
    "Share to chat" : "Podijeli u chat",
    "Dismiss notification" : "Zanemari obavijest",
    "Call recording now available" : "Snimka poziva je sada dostupna",
    "The recording for the call in {call} was uploaded to {file}." : "Snimka poziva u {call} prenesena je u {file}.",
    "Transcript now available" : "Pretvaranje snimke u tekst je sada dostupno",
    "The transcript for the call in {call} was uploaded to {file}." : "Pretvarenje snimke poziva u tekst u {call} prenesen je u {file}.",
    "Failed to transcript call recording" : "Pretvaranje snimke poziva u tekst nije uspjelo",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Poslužitelj nije uspio pretvoriti u tekst snimku na {file} za poziv u {call}. Obratite se administratoru.",
    "Call summary now available" : "Sažetak poziva je sada dostupan",
    "The summary for the call in {call} was uploaded to {file}." : "Sažetak poziva u {call} prenesen je u {file}.",
    "Failed to summarize call recording" : "Sažimanje snimke poziva nije uspjelo",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Poslužitelj nije uspio sažeti snimku na {file} za poziv u {call}. Obratite se administratoru.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} vas je pozvao da se pridružite {roomName} na {remoteServer}",
    "Accept" : "Prihvati",
    "Decline" : "Odbij",
    "{user1} invited you to a federated conversation" : "{user1} vas je pozvao u udruženi razgovor",
    "Someone reacted" : "Netko je reagirao",
    "New message" : "Nova poruka",
    "Reminder" : "Podsjetnik",
    "Someone mentioned you" : "Netko vas je spomenuo",
    "Notification" : "Obavijest",
    "Someone reacted in a private conversation" : "Netko je reagirao u privatnom razgovoru",
    "You received a message in a private conversation" : "Primili ste poruku u privatnom razgovoru",
    "Reminder in a private conversation" : "Podsjetnik u privatnom razgovoru",
    "Someone mentioned you in a private conversation" : "Netko vas je spomenuo u privatnom razgovoru",
    "Notification in a private conversation" : "Obavijest u privatnom razgovoru",
    "Reminder: You in {call}" : "Podsjetnik: Vi u {call}",
    "Reminder: {user} in {call}" : "Podsjetnik: {user} u {call}",
    "Reminder: Deleted user in {call}" : "Podsjetnik: Obrisani korisnik u {call}",
    "Reminder: {guest} (guest) in {call}" : "Podsjetnik: {guest} (gost) u {call}",
    "Reminder: Guest in {call}" : "Podsjetnik: Gost u {call}",
    "{user} reacted with {reaction}" : "{user} je reagirao s {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} je reagirao s {reaction} u {call}",
    "Deleted user reacted with {reaction} in {call}" : "Obrisani korisnik je reagirao s {reaction} u {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (gost) je reagirao s {reaction} u {call}",
    "Guest reacted with {reaction} in {call}" : "Gost je reagirao s {reaction} u {call}",
    "{user} in {call}" : "{user} u {call}",
    "Deleted user in {call}" : "Izbrisan korisnik u {call}",
    "{guest} (guest) in {call}" : "{guest} (gost) u {call}",
    "Guest in {call}" : "Gost u {call}",
    "{user} sent you a private message" : "{user} vam je poslao privatnu poruku",
    "{user} sent a message in conversation {call}" : "{user} je poslao poruku u razgovoru {call}",
    "A deleted user sent a message in conversation {call}" : "Izbrisani korisnik poslao je poruku u razgovoru {call}",
    "{guest} (guest) sent a message in conversation {call}" : "(gost) {guest} je poslao poruku u razgovoru {call}",
    "A guest sent a message in conversation {call}" : "Gost je poslao poruku u razgovoru {call}",
    "{user} replied to your private message" : "{user} je odgovorio na vašu privatnu poruku",
    "{user} replied to your message in conversation {call}" : "{user} je odgovorio na vašu poruku u razgovoru {call}",
    "A deleted user replied to your message in conversation {call}" : "Izbrisani korisnik odgovorio je na vašu poruku u razgovoru {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "(gost) {guest} je odgovorio na vašu poruku u razgovoru {call}",
    "A guest replied to your message in conversation {call}" : "Gost je odgovorio na vašu poruku u razgovoru {call}",
    "Reminder: You in private conversation {call}" : "Podsjetnik: Vi u privatnom razgovoru {call}",
    "Reminder: A deleted user in private conversation {call}" : "Podsjetnik: Obrisani korisnik u privatnom razgovoru {call}",
    "Reminder: {user} in private conversation" : "Podsjetnik: {user} u privatnom razgovoru",
    "Reminder: You in conversation {call}" : "Podsjetnik: Vi u razgovoru {call}",
    "Reminder: {user} in conversation {call}" : "Podsjetnik: {user} u razgovoru {call}",
    "Reminder: A deleted user in conversation {call}" : "Podsjetnik: Obrisani korisnik u razgovoru {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Podsjetnik: {guest} (gost) u razgovoru {call}",
    "Reminder: A guest in conversation {call}" : "Podsjetnik: Gost u razgovoru {call}",
    "{user} reacted with {reaction} to your private message" : "{user} je reagirao s {reaction} na vašu privatnu poruku",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} je reagirao s {reaction} na vašu poruku u razgovoru {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Obrisani korisnik je reagirao s {reaction} na vašu poruku u razgovoru {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (gost) je reagirao s {reaction} na vašu poruku u razgovoru {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Gost je reagirao s {reaction} na vašu poruku u razgovoru {call}",
    "{user} mentioned you in a private conversation" : "{user} vas je spomenuo u privatnom razgovoru",
    "{user} mentioned group {group} in conversation {call}" : "{user} je spomenuo grupu {group} u razgovoru {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} je spomenuo tim {team} u razgovoru {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} je spomenuo sve sudionike u razgovoru {call}",
    "{user} mentioned you in conversation {call}" : "{user} vas je spomenuo u razgovoru {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Obrisani korisnik je spomenuo grupu {group} u razgovoru {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Obrisani korisnik je spomenuo tim {team} u razgovoru {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Obrisani korisnik je spomenuo sve sudionike u razgovoru {call}",
    "A deleted user mentioned you in conversation {call}" : "Izbrisani korisnik spomenuo vas je u razgovoru {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (gost) je spomenuo grupu {group} u razgovoru {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (gost) je spomenuo tim {team} u razgovoru {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (gost) je spomenuo sve sudionike u razgovoru {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "(gost) {guest} vas je spomenuo u razgovoru {call}",
    "A guest mentioned group {group} in conversation {call}" : "Gost je spomenuo grupu {group} u razgovoru {call}",
    "A guest mentioned team {team} in conversation {call}" : "Gost je spomenuo tim {team} u razgovoru {call}",
    "A guest mentioned everyone in conversation {call}" : "Gost je spomenuo sve sudionike u razgovoru {call}",
    "A guest mentioned you in conversation {call}" : "Gost vas je spomenuo u razgovoru {call}",
    "View message" : "Prikaži poruku",
    "Dismiss reminder" : "Odbaci podsjetnik",
    "View chat" : "Prikaži razmjenu poruka",
    "{user} invited you to a group conversation: {call}" : "{user} vas je pozvao u grupni razgovor: {call}",
    "Join call" : "Pridruži se pozivu",
    "Answer call" : "Odgovori na poziv",
    "{user} would like to talk with you" : "{user} želi razgovarati s vama",
    "Call back" : "Nazovi natrag",
    "You missed a call from {user}" : "Propustili ste poziv od {user}",
    "Accept call" : "Prihvati poziv",
    "Incoming phone call from {call}" : "Dolazni telefonski poziv od {call}",
    "You missed a phone call from {call}" : "Propustili ste telefonski poziv od {call}",
    "A group call has started in {call}" : "Grupni poziv je pokrenut u {call}",
    "You missed a group call in {call}" : "Propustili ste grupni poziv u {call}",
    "{email} is requesting the password to access {file}" : "{email} traži zaporku za pristup {file}",
    "{email} tried to request the password to access {file}" : "{email} je pokušao zatražiti zaporku za pristup {file}",
    "Someone is requesting the password to access {file}" : "Netko traži zaporku za pristup {file}",
    "Someone tried to request the password to access {file}" : "Netko je pokušao zatražiti zaporku za pristup {file}",
    "Open settings" : "Otvori postavke",
    "Hosted signaling server added" : "Dodan je signalni poslužitelj",
    "The hosted signaling server is now configured and will be used." : "Signalni poslužitelj je konfiguriran i spreman za upotrebu.",
    "Hosted signaling server removed" : "Uklonjen je signalni poslužitelj",
    "The hosted signaling server was removed and will not be used anymore." : "Signalni poslužitelj je uklonjen i neće se upotrebljavati.",
    "Hosted signaling server changed" : "Promijenjen je signalni poslužitelj",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Račun signalnog poslužitelja je promijenio status iz „{oldstatus}” u „{newstatus}”.",
    "pending" : "na čekanju",
    "active" : "aktivno",
    "expired" : "isteklo",
    "blocked" : "blokirano",
    "error" : "pogreška",
    "The certificate of {host} expires in {days} days" : "Certifikat za {host} istječe za {days} dana",
    "The certificate of {host} expired" : "Certifikat za {host} je istekao",
    "Contact via Talk" : "Kontaktirajte putem aplikacije Talk",
    "Open Talk" : "Otvori Talk",
    "Default" : "Zadano",
    "Presentation" : "Prezentacija",
    "Voice room" : "Glasovna soba",
    "Webinar" : "Webinar",
    "Conversations" : "Razgovori",
    "Messages in current conversation" : "Poruke u trenutnom razgovoru",
    "{user}" : "{user}",
    "Messages" : "Poruke",
    "{user} in {conversation}" : "{user} u {conversation}",
    "Messages in other conversations" : "Poruke u ostalim razgovorima",
    "One-to-one rooms always need to show the other users avatar" : "Sobe jedan-na-jedan uvijek moraju prikazivati avatar drugog korisnika",
    "Invalid emoji character" : "Neispravan emoji znak",
    "Invalid background color" : "Neispravna boja pozadine",
    "Avatar image is not square" : "Slika avatara nije kvadratna",
    "Room {number}" : "Soba {number}",
    "Favorites" : "Favoriti",
    "Other" : "Drugo",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Zahtjev za probni rad nije upućen jer probni poslužitelj nije dostupan. Pokušajte ponovo kasnije.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Došlo je do poteškoća s autentifikacijom za ovu instancu. Možda joj nije moguće pristupiti izvana kako bi se provjerio njen URL.",
    "Something unexpected happened." : "Nešto se neočekivano dogodilo.",
    "The URL is invalid." : "URL je nevažeći.",
    "An HTTPS URL is required." : "Potreban je HTTPS URL.",
    "The email address is invalid." : "Nevažeća adresa e-pošte.",
    "The language is invalid." : "Jezik nije valjan.",
    "The country is invalid." : "Nevažeća država.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Došlo je do poteškoća s upućivanjem zahtjeva za probni rad. Provjerite zapisnike za više informacija.",
    "Too many requests are send from your servers address. Please try again later." : "S adrese poslužitelja šalje se previše zahtjeva. Pokušajte ponovo kasnije.",
    "There is already a trial registered for this Nextcloud instance." : "Za ovu instancu Nextclouda već postoji registriran probni račun.",
    "Something unexpected happened. Please try again later." : "Došlo je do neočekivane situacije. Pokušajte ponovo kasnije.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Zahtjev za probni rad nije upućen jer je probni poslužitelj neispravan. Pokušajte ponovo kasnije.",
    "Trial requested but failed to get account information. Please check back later." : "Probni rad je zatražen, ali nisu dohvaćene informacije o računu. Pokušajte kasnije.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Došlo je do poteškoća s autentifikacijom za ovaj zahtjev. Možda joj nije moguće pristupiti izvana kako bi se provjerio njen URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Informacije o računu nisu dohvaćene jer je probni poslužitelj neispravan. Pokušajte ponovo kasnije.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Došlo je do poteškoća s dohvaćanjem informacija o računu. Provjerite zapisnike za više informacija.",
    "There is no such account registered." : "Račun nije registriran.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Informacije o računu nisu dohvaćene jer je probni poslužitelj nedostupan. Pokušajte ponovo kasnije.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Brisanje računa pohranjenog signalnog poslužitelja nije uspjelo. Pokušajte kasnije.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Brisanje računa nije uspjelo jer je probni poslužitelj neispravan. Pokušajte ponovo kasnije.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Došlo je do poteškoća pri brisanju računa. Provjerite zapisnike za više informacija.",
    "Too many requests are sent from your servers address. Please try again later." : "S adrese poslužitelja šalje se previše zahtjeva. Pokušajte ponovo kasnije.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Brisanje računa nije uspjelo jer je probni poslužitelj nedostupan. Pokušajte ponovo kasnije.",
    "Note to self" : "Bilješka za sebe",
    "A place for your private notes, thoughts and ideas" : "Mjesto za vaše privatne bilješke, misli i ideje",
    "Transcript is AI generated and may contain mistakes" : "Pretvatanje snimke u tekst je generirala umjetna inteligencija i može sadržavati pogreške",
    "Summary is AI generated and may contain mistakes" : "Sažetak je generirala umjetna inteligencija i može sadržavati pogreške",
    "Let's get started!" : "Krenimo!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** je sigurna, samostalno hostana komunikacijska platforma koja se besprijekorno integrira s ekosustavom Nextcloud.\n\n#### Ključne značajke Nextcloud Talka:\n\n* Chat i razmjena poruka u privatnim i grupnim razgovorima\n* Glasovni i videopozivi\n* Dijeljenje datoteka i integracija s drugim Nextcloud aplikacijama\n* Prilagodljive postavke razgovora, moderiranje i kontrole privatnosti\n* Web, desktop i mobilno (iOS i Android)\n* Privatna i sigurna komunikacija\n\nSaznajte više u [korisničkoj dokumentaciji](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Dobro došli u Nextcloud Talk\n\nNextcloud Talk je privatna i moćna aplikacija za razmjenu poruka koja se integrira s Nextcloudom. Chatajte u privatnim ili grupnim razgovorima, surađujte putem glasovnih i videopoziva, organizirajte webinare i događaje, prilagodite svoje razgovore i još mnogo toga.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Formatirajte tekst za bogate poruke\n\nU Nextcloud Talku možete koristiti Markdown sintaksu za formatiranje poruka. Primjerice, primijenite **podebljano** ili *kurziv* formatiranje ili `istaknite tekst kao kod`. Možete čak izrađivati tablice i dodavati naslove u tekst.\n\nTreba ispraviti tipfeler ili promijeniti formatiranje? Uredite poruku klikom na \"Uredi poruku\" u izborniku poruke.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Dodajte privitke i poveznice\n\nPriložite datoteke iz svojeg Nextcloud Huba pomoću gumba \"+\". Dijelite stavke iz Datoteka i raznih Nextcloud aplikacija. Neke aplikacije podržavaju i interaktivne widgete, primjerice aplikacija Tekst.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Neka razgovori teku: spominjite korisnike, reagirajte na poruke i još mnogo toga\n\nMožete spomenuti sve u razgovoru koristeći %s ili spomenuti određene sudionike tako da upišete \"@\" i odaberete njihovo ime s popisa.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Možete odgovoriti na poruke, proslijediti ih u druge chatove i osobama ili kopirati sadržaj poruke.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Učinite više uz Pametni birač\n\nJednostavno upišite \"/\" ili otvorite izbornik \"+\" da biste otvorili Pametni birač, gdje možete priložiti razni sadržaj u poruke. Pametni birač možete podesiti tako da dodaje stavke iz Nextcloud aplikacija, GIF-ove, lokacije na karti, sadržaj koji generira AI i još mnogo toga.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Upravljajte postavkama razgovora\n\nU izborniku razgovora možete pristupiti raznim postavkama za upravljanje razgovorima, kao što su:\n* Uređivanje informacija o razgovoru\n* Upravljanje obavijestima\n* Primjena brojnih pravila moderiranja\n* Postavljanje pristupa i sigurnosti\n* Omogućavanje botova\n* i još mnogo toga!",
    "Andorra" : "Andora",
    "United Arab Emirates" : "Ujedinjeni Arapski Emirati",
    "Afghanistan" : "Afganistan",
    "Antigua and Barbuda" : "Antigva i Barbuda",
    "Anguilla" : "Angvila",
    "Albania" : "Albanija",
    "Armenia" : "Armenija",
    "Angola" : "Angola",
    "Antarctica" : "Antarktika",
    "Argentina" : "Argentina",
    "American Samoa" : "Američka Samoa",
    "Austria" : "Austrija",
    "Australia" : "Australija",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ålandski otoci",
    "Azerbaijan" : "Azerbajdžan",
    "Bosnia and Herzegovina" : "Bosna i Hercegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladeš",
    "Belgium" : "Belgija",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bugarska",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Sveti Bartolomej",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunej Darussalam",
    "Bolivia, Plurinational State of" : "Bolivija, Višenacionalna Država",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sveti Eustahije i Saba",
    "Brazil" : "Brazil",
    "Bahamas" : "Bahami",
    "Bhutan" : "Butan",
    "Bouvet Island" : "Otok Bouvet",
    "Botswana" : "Bocvana",
    "Belarus" : "Bjelorusija",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kokosov (Keeling) otok",
    "Congo, the Democratic Republic of the" : "Kongo, Demokratska Republika",
    "Central African Republic" : "Srednjoafrička Republika",
    "Congo" : "Kongo",
    "Switzerland" : "Švicarska",
    "Côte d'Ivoire" : "Obala Bjelokosti",
    "Cook Islands" : "Cookovo Otočje",
    "Chile" : "Čile",
    "Cameroon" : "Kamerun",
    "China" : "Kina",
    "Colombia" : "Kolumbija",
    "Costa Rica" : "Kostarika",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Zelenortska Republika",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Božićni Otok",
    "Cyprus" : "Cipar",
    "Czechia" : "Češka",
    "Germany" : "Njemačka",
    "Djibouti" : "Džibuti",
    "Denmark" : "Danska",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Dominikanska Republika",
    "Algeria" : "Alžir",
    "Ecuador" : "Ekvador",
    "Estonia" : "Estonija",
    "Egypt" : "Egipat",
    "Western Sahara" : "Zapadna Sahara",
    "Eritrea" : "Eritreja",
    "Spain" : "Španjolska",
    "Ethiopia" : "Etiopija",
    "Finland" : "Finska",
    "Fiji" : "Fidži",
    "Falkland Islands (Malvinas)" : "Falklandski otoci (Malvinas)",
    "Micronesia, Federated States of" : "Mikronezija, Federativne Države",
    "Faroe Islands" : "Farski otoci",
    "France" : "Francuska",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Ujedinjeno Kraljevstvo Velike Britanije i Sjeverne Irske",
    "Grenada" : "Grenada",
    "Georgia" : "Gruzija",
    "French Guiana" : "Francuska Gvajana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grenland",
    "Gambia" : "Gambija",
    "Guinea" : "Gvineja",
    "Guadeloupe" : "Gvadalupa",
    "Equatorial Guinea" : "Ekvatorijalna Gvineja",
    "Greece" : "Grčka",
    "South Georgia and the South Sandwich Islands" : "Južna Georgija i otočje Južni Sandwich",
    "Guatemala" : "Gvatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Gvineja Bisau",
    "Guyana" : "Gvajana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Otok Heard i otočje McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Hrvatska",
    "Haiti" : "Haiti",
    "Hungary" : "Mađarska",
    "Indonesia" : "Indonezija",
    "Ireland" : "Irska",
    "Israel" : "Izrael",
    "Isle of Man" : "Otok Man",
    "India" : "Indija",
    "British Indian Ocean Territory" : "Britanski Indijskooceanski teritorij",
    "Iraq" : "Irak",
    "Iran, Islamic Republic of" : "Iran, Islamska Republika",
    "Iceland" : "Island",
    "Italy" : "Italija",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordan",
    "Japan" : "Japan",
    "Kenya" : "Kenija",
    "Kyrgyzstan" : "Kirgistan",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komori",
    "Saint Kitts and Nevis" : "Sveti Kristofor i Nevis",
    "Korea, Democratic People's Republic of" : "Koreja, Demokratska Narodna Republika",
    "Korea, Republic of" : "Koreja, Republika",
    "Kuwait" : "Kuvajt",
    "Cayman Islands" : "Kajmanski Otoci",
    "Kazakhstan" : "Kazahstan",
    "Lao People's Democratic Republic" : "Laoska Narodna Demokratska Republika",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Sveta Lucija",
    "Liechtenstein" : "Lihtenštajn",
    "Sri Lanka" : "Šri Lanka",
    "Liberia" : "Liberija",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Litva",
    "Luxembourg" : "Luksemburg",
    "Latvia" : "Latvija",
    "Libya" : "Libija",
    "Morocco" : "Maroko",
    "Monaco" : "Monako",
    "Moldova, Republic of" : "Moldavija, Republika",
    "Montenegro" : "Crna Gora",
    "Saint Martin (French part)" : "Sveti Martin (francuski dio)",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Maršalovi Otoci",
    "North Macedonia" : "Sjeverna Makedonija",
    "Mali" : "Mali",
    "Myanmar" : "Mjanmar",
    "Mongolia" : "Mongolija",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Sjevernomarijanski otoci",
    "Martinique" : "Martinik",
    "Mauritania" : "Mauritanija",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauricijus",
    "Maldives" : "Maldivi",
    "Malawi" : "Malavi",
    "Mexico" : "Meksiko",
    "Malaysia" : "Malezija",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibija",
    "New Caledonia" : "Nova Kaledonija",
    "Niger" : "Niger",
    "Norfolk Island" : "Otok Norfolk",
    "Nigeria" : "Nigerija",
    "Nicaragua" : "Nikaragva",
    "Netherlands" : "Nizozemska",
    "Norway" : "Norveška",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Novi Zeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Francuska Polinezija",
    "Papua New Guinea" : "Papua Nova Gvineja",
    "Philippines" : "Filipini",
    "Pakistan" : "Pakistan",
    "Poland" : "Poljska",
    "Saint Pierre and Miquelon" : "Sveti Petar i Mikelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Portoriko",
    "Palestine, State of" : "Palestina, Država",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paragvaj",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Rumunjska",
    "Serbia" : "Srbija",
    "Russian Federation" : "Ruska Federacija",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudijska Arabija",
    "Solomon Islands" : "Salomonski Otoci",
    "Seychelles" : "Sejšeli",
    "Sudan" : "Sudan",
    "Sweden" : "Švedska",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sveta Helena, Ascension i Tristan da Cunha",
    "Slovenia" : "Slovenija",
    "Svalbard and Jan Mayen" : "Svalbard i Jan Mayen",
    "Slovakia" : "Slovačka",
    "Sierra Leone" : "Sijera Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalija",
    "Suriname" : "Surinam",
    "South Sudan" : "Južni Sudan",
    "Sao Tome and Principe" : "Sveti Toma i Princip",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (nizozemski dio)",
    "Syrian Arab Republic" : "Sirijska Arapska Republika",
    "Eswatini" : "Esvatini",
    "Turks and Caicos Islands" : "Otoci Turks i Caicos",
    "Chad" : "Čad",
    "French Southern Territories" : "Francuski južni teritoriji",
    "Togo" : "Togo",
    "Thailand" : "Tajland",
    "Tajikistan" : "Tadžikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Istočni Timor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunis",
    "Tonga" : "Tonga",
    "Turkey" : "Turska",
    "Trinidad and Tobago" : "Trinidad i Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Tajvan, Provincija NR Kine",
    "Tanzania, United Republic of" : "Ujedinjena Republika Tanzanija",
    "Ukraine" : "Ukrajina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Mali udaljeni otoci SAD-a",
    "United States of America" : "Sjedinjene Američke Države",
    "Uruguay" : "Urugvaj",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Sveta Stolica",
    "Saint Vincent and the Grenadines" : "Sveti Vincent i Grenadini",
    "Venezuela, Bolivarian Republic of" : "Venezuela, Bolivarijska Republika",
    "Virgin Islands, British" : "Djevičanski otoci, britanski",
    "Virgin Islands, U.S." : "Djevičanski otoci, SAD",
    "Viet Nam" : "Vijetnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis i Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Južna Afrika",
    "Zambia" : "Zambija",
    "Zimbabwe" : "Zimbabve",
    "Background blur" : "Zamućenje pozadine",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Nije moguće provjeriti podršku za učitavanje WASM-a. Ručno provjerite poslužuje li vaš web-poslužitelj datoteke `.wasm`.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Vaš web-poslužitelj nije ispravno podešen za isporuku datoteka `.wasm`. To je obično problem u konfiguraciji Nginxa. Za zamućenje pozadine potrebno je prilagoditi konfiguraciju tako da također poslužuje datoteke `.wasm`. Usporedite svoju Nginx konfiguraciju s preporučenom konfiguracijom u našoj dokumentaciji.",
    "Talk configuration values" : "Vrijednosti konfiguracije Talka",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Prisiljavanje trajanja poziva podržano je samo uz sistemski cron. Omogućite sistemski cron ili uklonite konfiguraciju `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Male vrijednosti `max_call_duration` (trenutačno postavljeno na %d) nije moguće provesti zbog tehničkih ograničenja. Pozadinski posao izvršava se samo svakih 5 minuta, pa koristite na vlastitu odgovornost.",
    "Federation" : "Udruženje",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Preporučuje se konfigurirati \"memcache.locking\" kada je omogućena Talk udruženje.",
    "High-performance backend" : "Visokoučinkovit pozadinski sustav",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Nije konfiguriran visokoučinkoviti pozadinski sustav – pokretanje Nextcloud Talka bez visokoučinkovitog pozadinskog sustava skalira samo za vrlo male pozive (najviše 2–3 sudionika). Postavite visokoučinkoviti pozadinski sustav kako bi pozivi s više sudionika radili besprijekorno.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Pokretanje visokoučinkovitog pozadinskog sustava u načinu \"conversation_cluster\" je zastarjelo i više neće biti podržano u nadolazećoj verziji. Visokoučinkoviti pozadinski sustav danas podržava pravo klasteriranje i to bi se trebalo koristiti umjesto toga.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Definiranje više visokoučinkovitih pozadinskih sustava je zastarjelo i više neće biti podržano u nadolazećoj verziji. Umjesto toga treba postaviti uravnoteživač opterećenja zajedno s klasteriranim signalnim poslužiteljima i konfigurirati ga u postavkama Talka.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "Spremljeni javni ključ za korišteni algoritam %1$s ne odgovara spremljenom privatnom ključu. Pokrenite %2$s da biste ispravili problem.",
    "High-performance backend not configured correctly. Run %s for details." : "Visokoučinkoviti pozadinski sustav nije ispravno konfiguriran. Pokrenite %s za detalje.",
    "High-performance backend not configured correctly" : "Visokoučinkoviti pozadinski sustav nije ispravno konfiguriran",
    "Error: Cannot connect to server" : "Pogreška: povezivanje s poslužiteljem nije uspjelo",
    "Error: Server did not respond with proper JSON" : "Pogreška: poslužitelj nije vratio točan JSON",
    "Error: Certificate expired" : "Pogreška: Certifikat je istekao",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Pogreška: Sustavna vremena Nextcloud poslužitelja i poslužitelja visokoučinkovitog pozadinskog sustava nisu usklađena. Provjerite jesu li oba poslužitelja povezana s poslužiteljem vremena ili ručno sinkronizirajte vrijeme.",
    "Could not get version" : "Nije moguće dohvatiti verziju",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Pogreška: Pokrenuta verzija: {version}; poslužitelj se mora ažurirati kako bi bio kompatibilan s ovom verzijom Talka",
    "Error: Server responded with: {error}" : "Pogreška: poslužitelj je vratio: {error}",
    "Error: Unknown error occurred" : "Pogreška: došlo je do nepoznate pogreške",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Upozorenje: Pokrenuta verzija: {version}; poslužitelj ne podržava sve značajke ove verzije Talka, nedostaju značajke: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Preporučuje se konfigurirati memorijsku predmemoriju pri pokretanju Nextcloud Talka s visokoučinkovitim pozadinskim sustavom.",
    "Client Push" : "Client Push",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "Client Push je instaliran, što poboljšava pravovremenost Talk obavijesti.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} nije instaliran. To može dovesti do odgođenih Talk obavijesti.",
    "Recording backend" : "Pozadinski sustav za snimanje",
    "Using the recording backend requires a High-performance backend." : "Korištenje pozadinskog sustava za snimanje zahtijeva visokoučinkoviti pozadinski sustav.",
    "No recording backend configured" : "Nije konfiguriran pozadinski sustav za snimanje",
    "SIP configuration" : "Konfiguracija SIP-a",
    "Using the SIP functionality requires a High-performance backend." : "Korištenje SIP funkcionalnosti zahtijeva visokoučinkoviti pozadinski sustav.",
    "Assigned Talk phone numbers must not start with + or 0. Please remove or update the following numbers:\n{list}" : "Dodijeljeni telefonski brojevi za Talk ne smiju započinjati s + ili 0. Uklonite ili ažurirajte sljedeće brojeve:\n{list}",
    "No SIP backend configured" : "Nije konfiguriran SIP pozadinski sustav",
    "Invalid date, date format must be YYYY-MM-DD" : "Nevažeći datum, oblik datuma mora biti GGGG-MM-DD",
    "Conversation not found" : "Razgovor nije pronađen",
    "Path is already shared with this conversation" : "Putanja je već dijeljena s ovim razgovorom",
    "Chat, video & audio-conferencing using WebRTC" : "Razmjena poruka, videopozivi i glasovne konferencije putem WebRTC-a",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Chat, video i audiokonferencije putem WebRTC-a\n\n* 💬 **Chat** Nextcloud Talk dolazi s jednostavnim tekstualnim chatom koji vam omogućuje dijeljenje ili prijenos datoteka iz aplikacije Nextcloud Datoteke ili s lokalnog uređaja te spominjanje drugih sudionika.\n* 👥 **Privatni, grupni, javni i lozinkom zaštićeni pozivi!** Pozovite nekoga, cijelu grupu ili pošaljite javnu poveznicu za poziv.\n* 🌐 **Udruženi chatovi** Chatajte s drugim Nextcloud korisnicima na njihovim poslužiteljima\n* 💻 **Dijeljenje zaslona!** Podijelite svoj zaslon sa sudionicima poziva.\n* 🚀 **Integracija s drugim Nextcloud aplikacijama** kao što su Datoteke, Kalendar, Status korisnika, Nadzorna ploča, Flow, Karte, Pametni birač, Kontakti, Deck i mnoge druge.\n* 🌉 **Sinkronizacija s drugim chat rješenjima** Budući da je [Matterbridge](https://github.com/42wim/matterbridge/) integriran u Talk, možete jednostavno sinkronizirati mnoga druga chat rješenja s Nextcloud Talkom i obrnuto.",
    "Leave call" : "Napusti poziv",
    "Navigating away from the page will leave the call in {conversation}" : "Zatvaranjem stranice napustit ćete poziv u {conversation}",
    "Stay in call" : "Ostani u pozivu",
    "Error occurred when getting the conversation information" : "Došlo je do pogreške pri dohvaćanju informacija o razgovoru",
    "Duplicate session" : "Udvostruči sesiju",
    "Discuss this file" : "Raspravi o ovoj datoteci",
    "Loading …" : "Učitavanje…",
    "Share this file with others to discuss it" : "Podijeli ovu datoteku s drugima radi rasprave",
    "Join conversation" : "Pridruži se razgovoru",
    "Share this file" : "Dijeli ovu datoteku",
    "Error occurred when joining the conversation" : "Došlo je do pogreške pri pridruživanju razgovoru",
    "This conversation is password-protected." : "Ovaj razgovor je zaštićen lozinkom.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Otkrili smo više neispravnih pokušaja unosa lozinke s vaše IP adrese. Stoga je vaš sljedeći pokušaj ograničen do 30 sekundi.",
    "The password is wrong. Try again." : "Pogrešna zaporka. Pokušajte ponovno.",
    "Password" : "Zaporka",
    "Submit" : "Šalji",
    "Error requesting the password." : "Pogreška pri traženju zaporke.",
    "Request password" : "Zatraži zaporku",
    "This conversation has ended" : "Ovaj je razgovor završio",
    "Close Talk sidebar" : "Zatvori Talk bočnu traku",
    "Open Talk sidebar" : "Otvori Talk bočnu traku",
    "Everyone" : "Svi",
    "Users and moderators" : "Korisnici i moderatori",
    "Moderators only" : "Samo moderatori",
    "Disable calls" : "Onemogući pozive",
    "Save changes" : "Spremi promjene",
    "Saving …" : "Spremanje...",
    "Saved!" : "Spremljeno!",
    "Limit to groups" : "Ograniči na grupe",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Kada je odabrana barem jedna grupa, samo članovi navedenih grupa mogu sudjelovati u razgovorima.",
    "Guests can still join public conversations." : "Gosti se i dalje mogu pridružiti javnim razgovorima.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Korisnici koji više ne mogu upotrebljavati aplikaciju Talk i dalje će biti navedeni kao sudionici u svojim završenim razgovorima i čuvat će se njihove razmijenjene poruke.",
    "Limit using Talk" : "Ograniči korištenje aplikacije Talk",
    "Limit creating a public and group conversation" : "Ograniči stvaranje javnih i grupnih razgovora",
    "Limit creating conversations" : "Ograniči stvaranje razgovora",
    "Limit starting a call" : "Ograniči upućivanje poziva",
    "Limit starting calls" : "Ograniči upućivanje poziva",
    "When a call has started, everyone with access to the conversation can join the call." : "Nakon uspostavljanja, pozivu se može pridružiti svatko kome je odobren pristup razgovoru.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Sljedeći botovi instalirani su na ovom poslužitelju. U dokumentaciji možete pronaći detalje kako {linkstart1}izraditi vlastitog bota{linkend} ili {linkstart2}popis botova{linkend} koje možete omogućiti na poslužitelju.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Na ovom poslužitelju nisu instalirani botovi. U dokumentaciji možete pronaći detalje kako {linkstart1}izraditi vlastitog bota{linkend} ili {linkstart2}popis botova{linkend} koje možete omogućiti na poslužitelju.",
    "Description is not provided" : "Opis nije naveden",
    "Locked for moderators" : "Zaključano za moderatore",
    "Enabled" : "Omogućeno",
    "Disabled" : "Onemogućeno",
    "Bots settings" : "Postavke botova",
    "State" : "Stanje",
    "Name" : "Naziv",
    "Last error" : "Zadnja pogreška",
    "Total errors count" : "Ukupan broj pogrešaka",
    "Find more bots" : "Pronađi više botova",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Pouzdani poslužitelji mogu se konfigurirati na {linkstart}stranici postavki dijeljenja{linkend}.",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Udruženi chatovi i pozivi već rade. Rukovanje privicima dolazi u budućoj verziji.",
    "Enable Federation in Talk app" : "Omogući udruživanje u aplikaciji Talk",
    "Permissions" : "Dopuštenja",
    "Allow users to be invited to federated conversations" : "Dopusti pozivanje korisnika u udružene razgovore",
    "Allow users to invite federated users into conversation" : "Dopusti korisnicima pozivanje udruženih korisnika u razgovor",
    "Only allow to federate with trusted servers" : "Dopusti udruženje samo s pouzdanim poslužiteljima",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Kada je odabrana barem jedna grupa, samo osobe iz navedenih grupa mogu pozivati udružene korisnike u razgovore.",
    "Groups allowed to invite federated users" : "Grupe koje smiju pozivati udružene korisnike",
    "Select groups …" : "Odaberite grupe …",
    "All messages" : "Sve poruke",
    "@-mentions only" : "Samo @-spominjanja",
    "Off" : "Isključeno",
    "General settings" : "Opće postavke",
    "Default notification settings" : "Zadane postavke obavijesti",
    "Default group notification" : "Zadane obavijesti grupe",
    "Default group notification for new groups" : "Zadane obavijesti grupe za nove grupe",
    "Integration into other apps" : "Integracija s drugim aplikacijama",
    "Allow conversations on files" : "Dopusti razgovore na datotekama",
    "Allow conversations on public shares for files" : "Dopusti razgovore na javnim dijeljenjima za datoteke",
    "End-to-end encrypted calls" : "Pozivi s end-to-end enkripcijom",
    "Enable encryption" : "Omogući šifriranje",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Pozivi s end-to-end enkripcijom uz konfiguriran SIP most zahtijevaju noviju verziju visokoučinkovitog pozadinskog sustava i SIP mosta.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Mobilni klijenti trenutačno ne podržavaju pozive s end-to-end enkripcijom.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Informacije iz obrasca poslat će se tvrtki Struktur AG ako kliknete na gumb iznad. Više informacija možete pronaći na {linkstart}spreed.eu{linkend}.",
    "Pending" : "Na čekanju",
    "Error" : "Pogreška",
    "Blocked" : "Blokiran",
    "Active" : "Aktivan",
    "Expired" : "Istekao",
    "Never" : "Nikad",
    "The trial could not be requested. Please try again later." : "Nije moguće zatražiti probni rad. Pokušajte ponovo kasnije.",
    "The account could not be deleted. Please try again later." : "Nije moguće izbrisati račun. Pokušajte ponovo kasnije.",
    "Hosted High-performance backend" : "Visokoučinkoviti pozadinski sustav na poslužitelju",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Naš partner Struktur AG pruža uslugu putem koje možete zatražiti signalni poslužitelj. Trebate ispuniti obrazac u nastavku i vaš će Nextcloud zatražiti signalni poslužitelj. Vjerodajnice se automatski popunjavaju nakon postavljanja poslužitelja. Time ćete prebrisati postavke postojećeg signalnog poslužitelja.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Ako vaš račun visokoučinkovitog pozadinskog sustava uključuje STUN i/ili TURN funkcionalnost, postavke će se ažurirati u skladu s tim.",
    "URL of this Nextcloud instance" : "URL ove instance Nextclouda",
    "Full name of the user requesting the trial" : "Puno ime korisnika koji je zatražio probu",
    "Email of the user" : "Adresa e-pošte korisnika",
    "Language" : "Jezik",
    "Country" : "Država",
    "Request signaling server trial" : "Zatraži probu signalnog poslužitelja",
    "You can see the current status of your hosted signaling server in the following table." : "Trenutni status signalnog poslužitelja možete pronaći u sljedećoj tablici.",
    "Status" : "Status",
    "Created at" : "Stvoreno",
    "Expires at" : "Istječe u",
    "Limits" : "Ograničenja",
    "STUN included" : "STUN uključen",
    "Yes" : "Da",
    "No" : "Ne",
    "TURN included" : "TURN uključen",
    "Delete the signaling server account" : "Brisanje računa signalnog poslužitelja",
    "_%n user_::_%n users_" : ["%n korisnik","%n korisnika","%n korisnika"],
    "Installed version: {version}" : "Instalirana inačica: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Možete instalirati Matterbridge kako biste povezali Nextcloud Talk s nekim drugim uslugama. Posjetite njihovu {linkstart1}GitHub stranicu{linkend} za više detalja. Preuzimanje i instalacija aplikacije može potrajati. Ako dođe do isteka vremena, instalirajte je ručno iz {linkstart2}Nextcloud App Storea{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "Matterbridge binarna datoteka ima neispravna dopuštenja. Provjerite je li binarna datoteka Matterbridge u vlasništvu ispravnog korisnika i može li se izvršavati. Nalazi se u \"/…/nextcloud/apps/talk_matterbridge/bin/\".",
    "Matterbridge binary was not found or couldn't be executed." : "Binarna datoteka Matterbridge nije pronađena ili se ne može izvršiti.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Put do binarnog programa Matterbridge također možete ručno postaviti u samoj konfiguraciji. Dodatne informacije potražite u {linkstart}dokumentaciji za integraciju Matterbridgea{linkend}.",
    "Downloading …" : "Preuzimanje…",
    "Install Talk Matterbridge" : "Instalirajte Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Došlo je do pogreške pri instalaciji aplikacije Matterbridge",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Došlo je do pogreške pri instalaciji Talk Matterbridgea. Instalirajte ga ručno",
    "Failed to execute Matterbridge binary." : "Izvršavanje binarne datoteke Matterbridge nije uspjelo.",
    "Matterbridge integration" : "Matterbridge integracija",
    "Enable Matterbridge integration" : "Omogućite Matterbridge integraciju",
    "Status: Checking connection" : "Status: provjeravanje veze",
    "OK: Running version: {version}" : "U redu: trenutna inačica: {version}",
    "Error: Server seems to be a Signaling server" : "Pogreška: Poslužitelj se čini signalnim poslužiteljem",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Pogreška: Sustavna vremena Nextcloud poslužitelja i poslužitelja pozadinskog sustava za snimanje nisu usklađena. Provjerite jesu li oba poslužitelja povezana s poslužiteljem vremena ili ručno sinkronizirajte vrijeme.",
    "Recording backend URL" : "URL pozadinskog sustava za snimanje",
    "Validate SSL certificate" : "Potvrdi vjerodajnicu SSL-a",
    "Delete this server" : "Izbriši ovaj poslužitelj",
    "Test this server" : "Ispitaj ovaj poslužitelj",
    "Disabled for all calls" : "Onemogućeno za sve pozive",
    "Enabled for all calls" : "Omogućeno za sve pozive",
    "Configurable on conversation level by moderators" : "Moguće je podesiti na razini razgovora od strane moderatora",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "PHP postavke \"upload_max_filesize\" ili \"post_max_size\" omogućit će prijenos datoteka samo do {maxUpload}.",
    "Recording backend settings saved" : "Postavke pozadinskog sustava za snimanje su spremljene",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Moderatorima će biti dopušteno omogućiti privolu na razini razgovora. Privola za snimanje bit će potrebna za svakog sudionika prije pridruživanja svakom pozivu u ovom razgovoru.",
    "The consent to be recorded will be required for each participant before joining every call." : "Privola za snimanje bit će potrebna za svakog sudionika prije pridruživanja svakom pozivu.",
    "The consent to be recorded is not required." : "Privola za snimanje nije potrebna.",
    "Recording backend configuration is only possible with a High-performance backend." : "Konfiguracija pozadinskog sustava za snimanje moguća je samo uz visokoučinkoviti pozadinski sustav.",
    "Add a new recording backend server" : "Dodaj novi poslužitelj pozadinskog sustava za snimanje",
    "Shared secret" : "Dijeljen tajni ključ",
    "Recording consent" : "Privola za snimanje",
    "Recording transcription" : "Pretvaranje snimke u tekst",
    "Automatically transcribe call recordings with a transcription provider" : "Automatski pretvori snimke poziva u tekst uz pružatelja",
    "Automatically summarize call recordings with transcription and summary providers" : "Automatski sažmi snimke poziva uz pružatelje pretvanja u tekst i sažetaka",
    "SIP configuration saved!" : "SIP konfiguracija je spremljena!",
    "SIP configuration is only possible with a High-performance backend." : "SIP konfiguracija moguća je samo uz visokoučinkoviti pozadinski sustav.",
    "Enable SIP Dial-out option" : "Omogući opciju SIP biranja prema van",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Signalni poslužitelj mora se ažurirati kako bi podržavao značajku SIP biranja prema van.",
    "Do not show SIP Dial-out caller number" : "Ne prikazuj broj pozivatelja za SIP biranje prema van",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Anoniman broj trebao bi se primatelju poziva prikazati kao \"unknown\" ili \"withheld number\"",
    "Dial-out number" : "Broj za biranje prema van",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Broj u E164 formatu koji se koristi kao rezervni broj pozivatelja za odlazne pozive",
    "Dial-out prefix" : "Prefiks biranja prema van",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Prefiks koji se dodaje na konfigurirani korisnički broj za odlazne pozive (zadano je `+`)",
    "Restrict SIP configuration" : "Ograniči konfiguraciju SIP-a",
    "Enable SIP configuration" : "Omogući konfiguraciju SIP-a",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Samo korisnici iz sljedećih grupa mogu omogućiti SIP u razgovorima koje moderiraju",
    "Phone number (Country)" : "Broj telefona (država)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Ove se informacije šalju u porukama e-pošte s pozivnicama i prikazuju se u bočnoj traci sudionika.",
    "Nextcloud base URL" : "Osnovni URL Nextclouda",
    "Talk Backend URL" : "URL Talk pozadinskog sustava",
    "WebSocket URL" : "WebSocket URL",
    "Available features" : "Dostupne značajke",
    "Error: Websocket connection failed" : "Pogreška: WebSocket veza nije uspjela",
    "Error code" : "Kôd pogreške",
    "Error message" : "Poruka o pogrešci",
    "Error: Websocket connection failed. Check browser console" : "Pogreška: WebSocket veza nije uspjela. Provjerite konzolu preglednika",
    "High-performance backend URL" : "URL visokoučinkovitog pozadinskog sustava",
    "Missing High-performance backend warning hidden" : "Upozorenje o nedostajućem visokoučinkovitom pozadinskom sustavu je skriveno",
    "High-performance backend settings saved" : "Postavke visokoučinkovitog pozadinskog sustava su spremljene",
    "Nextcloud Talk setup not complete" : "Postavljanje Nextcloud Talka nije dovršeno",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Napomena: u pozivima s više od 2 sudionika bez visokoučinkovitog pozadinskog sustava sudionici će vrlo vjerojatno imati probleme s povezivošću, a sudjelujući uređaji bit će snažno opterećeni.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Instalirajte visokoučinkoviti pozadinski sustav kako bi pozivi s više sudionika radili besprijekorno.",
    "Nextcloud portal" : "Nextcloud portal",
    "Quick installation guide" : "Kratki vodič za instalaciju",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Visokoučinkoviti pozadinski sustav potreban je za pozive i razgovore s više sudionika. Bez pozadinskog sustava svi sudionici moraju zasebno slati vlastiti video svakom drugom sudioniku, što će vrlo vjerojatno uzrokovati probleme s povezivošću i veliko opterećenje sudjelujućih uređaja.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Preporučuje se postaviti distribuiranu predmemoriju pri korištenju Nextcloud Talka s visokoučinkovitim pozadinskim sustavom.",
    "Add High-performance backend server" : "Dodaj poslužitelj visokoučinkovitog pozadinskog sustava",
    "Warn about connectivity issues in calls with more than 2 participants" : "Upozori na probleme s povezivošću u pozivima s više od 2 sudionika",
    "STUN server URL" : "URL poslužitelja STUN",
    "The server address is invalid" : "Adresa poslužitelja nije valjana",
    "STUN settings saved" : "STUN postavke su spremljene",
    "STUN servers" : "Poslužitelji STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Poslužitelj STUN upotrebljava se za određivanje javne IP adrese sudionika iza usmjerivača.",
    "Add a new STUN server" : "Dodaj novi STUN poslužitelj",
    "{schema} scheme must be used with a domain" : "Shema {schema} mora se upotrebljavati s domenom",
    "{option1} and {option2}" : "{option1} i {option2}",
    "{option} only" : "Samo {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "U redu: poslužitelj TURN vratio je uspješne ICE kandidate",
    "Error: No working ICE candidates returned by the TURN server" : "Pogreška: poslužitelj TURN nije vratio ispravne ICE kandidate",
    "Testing whether the TURN server returns ICE candidates" : "Ispitivanje hoće li poslužitelj TURN vratiti ICE kandidate",
    "TURN server schemes" : "Sheme poslužitelja TURN",
    "TURN server URL" : "URL poslužitelja TURN",
    "TURN server secret" : "Tajni ključ poslužitelja TURN",
    "TURN server protocols" : "Protokoli poslužitelja TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Poslužitelj TURN upotrebljava se za usmjeravanje prometa sudionika iza vatrozida. Ako se pojedini sudionici ne mogu povezati s drugim sudionicima, vjerojatno je potreban poslužitelj TURN. Upute za postavljanje poslužitelja možete pronaći u {linkstart}ovoj dokumentaciji{linkend}.",
    "TURN settings saved" : "TURN postavke su spremljene",
    "TURN servers" : "Poslužitelji TURN",
    "Add a new TURN server" : "Dodaj novi TURN poslužitelj",
    "Failed" : "Neuspjelo",
    "OK" : "U redu",
    "Checking …" : "Provjera …",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Neuspjelo: WebAssembly je onemogućen ili ga ovaj preglednik ne podržava. Omogućite WebAssembly ili koristite preglednik koji ga podržava kako biste proveli provjeru.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Neuspjelo: web-poslužitelj nije ispravno vratio datoteke \".wasm\" i \".tflite\". Provjerite odjeljak \"Sistemski zahtjevi\" u Talk dokumentaciji.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "U redu: web-poslužitelj je ispravno vratio datoteke \".wasm\" i \".tflite\".",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Čini se da PHP i Apache konfiguracija nisu kompatibilne. Imajte na umu da se PHP može koristiti samo s modulom MPM_PREFORK, a PHP-FPM samo s modulom MPM_EVENT.",
    "Web server setup checks" : "Provjere postavljanja web-poslužitelja",
    "Files required for virtual background can be loaded" : "Datoteke potrebne za virtualnu pozadinu mogu se učitati",
    "Federated user" : "Udruženi korisnik",
    "Assign participants to rooms" : "Dodijeli sudionike u sobe",
    "Configure breakout rooms" : "Konfiguriraj sobe za odvajanje",
    "Number of breakout rooms" : "Broj soba za odvajanje",
    "You can create from 1 to 20 breakout rooms." : "Možete stvoriti od 1 do 20 soba za odvajanje.",
    "Assignment method" : "Način dodjele",
    "Automatically assign participants" : "Automatski dodijeli sudionike",
    "Manually assign participants" : "Ručno dodijeli sudionike",
    "Allow participants to choose" : "Dopusti sudionicima odabir",
    "Create rooms" : "Stvori sobe",
    "Confirm" : "Potvrdi",
    "Create breakout rooms" : "Stvori sobe za odvajanje",
    "Reset" : "Resetiraj",
    "Delete breakout rooms" : "Izbriši sobe za odvajanje",
    "Room {roomNumber}" : "Soba {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Trenutačne sobe za odvajanje i postavke bit će izgubljene",
    "Cancel" : "Odustani",
    "Unassigned participants" : "Nedodijeljeni sudionici",
    "Back" : "Natrag",
    "Assign" : "Dodijeli",
    "Add participant \"{user}\"" : "Dodaj sudionika „{user}”",
    "Now" : "Sada",
    "Invalid calendar selected" : "Odabran je neispravan kalendar",
    "Invalid start time selected" : "Odabrano je neispravno vrijeme početka",
    "Invalid end time selected" : "Odabrano je neispravno vrijeme završetka",
    "Unknown error occurred" : "Došlo je do nepoznate pogreške",
    "Sending no invitations" : "Ne šalju se pozivnice",
    "{participant0} will receive an invitation" : "{participant0} će primiti pozivnicu",
    "{participant0} and {participant1} will receive invitations" : "{participant0} i {participant1} će primiti pozivnice",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} i još %n osoba primit će pozivnicu","{participant0}, {participant1} i još %n osobe primit će pozivnice","{participant0}, {participant1} i još %n osoba primit će pozivnice"],
    "Invite {user}" : "Pozovi {user}",
    "Invite all users and emails in this conversation" : "Pozovi sve korisnike i adrese e-pošte u ovom razgovoru",
    "Meeting created" : "Sastanak je stvoren",
    "Upcoming meetings" : "Nadolazeći sastanci",
    "No upcoming meetings" : "Nema nadolazećih sastanaka",
    "Schedule a meeting" : "Zakaži sastanak",
    "Meeting title" : "Naslov sastanka",
    "From" : "Od",
    "To" : "Za",
    "Calendar" : "Kalendar",
    "Attendees" : "Sudionici",
    "No other participants to send invitations to." : "Nema drugih sudionika kojima bi se poslale pozivnice.",
    "Add attendees" : "Dodaj sudionike",
    "Save" : "Spremi",
    "Search participants" : "Pretraži sudionike",
    "No results" : "Nema rezultata",
    "Done" : "Gotovo",
    "Disable live transcription" : "Onemogući pretvaranje u tekst uživo",
    "Enable live transcription (generated by AI)" : "Omogući pretvaranje u tekst uživo (generirano umjetnom inteligencijom)",
    "Enable live transcription (Live transcriptions app is not installed)" : "Omogući pretvaranje u tekst uživo (Aplikacija generiranja umjetnom inteligencijom nije instalirana)",
    "Disable live translation" : "Onemogući prijevod uživo",
    "Enable live translation (generated by AI)" : "Omogući prijevod uživo (generirano umjetnom inteligencijom)",
    "Original language" : "Originalni jezik",
    "Live translations app is not installed" : "Aplikacija za prijevod uživo nije instalirana",
    "Original language: {languageName}" : "Izvorni jezik: {languageName}",
    "Translated language" : "Prevedeni jezik",
    "Translated language: {languageName}" : "Prevedeni jezik: {languageName}",
    "Exit full screen (F)" : "Izađi iz prikaza preko cijelog zaslona (F)",
    "Full screen (F)" : "Prikaz preko cijelog zaslona (F)",
    "Speaker view" : "Prikaz govornika",
    "Grid view" : "Prikaz rešetke",
    "Error when trying to load the available live transcription languages" : "Pogreška pri učitavanju dostupnih jezika za pretvaranje u tekst uživo",
    "Failed to enable live transcription" : "Nije uspjelo omogućiti pretvaranje u tekst uživo",
    "Failed to enable live translations" : "Nije uspjelo omogućiti prijevode uživo",
    "Failed to disable live translations" : "Nije uspjelo onemogućiti prijevode uživo",
    "Recording consent is required" : "Potrebna je privola za snimanje",
    "This conversation is read-only" : "Ovaj razgovor je samo za čitanje",
    "Conversation not found or not joined" : "Razgovor nije pronađen ili mu niste pristupili",
    "Lobby is still active and you're not a moderator" : "Predvorje je još aktivno, a vi niste moderator",
    "Connection failed" : "Povezivanje nije uspjelo",
    "Reload" : "Ponovno učitaj",
    "{nickName} raised their hand." : "{nickName} je podigao ruku.",
    "A participant raised their hand." : "Sudionik je podigao ruku.",
    "Collapse stripe" : "Sakrij traku",
    "Expand stripe" : "Proširi traku",
    "Previous page of videos" : "Prethodna stranica s videozapisima",
    "Next page of videos" : "Sljedeća stranica s videozapisima",
    "Connecting …" : "Povezivanje…",
    "Calling …" : "Pozivanje …",
    "Waiting for {user} to join the call" : "Čeka se da se {user} pridruži pozivu",
    "Waiting for others to join the call …" : "Čekaju se drugi sudionici da se pridruže pozivu...",
    "You can invite others in the participant tab of the sidebar" : "Druge sudionike možete pozvati putem kartice sudionika na bočnoj traci",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Druge sudionike možete pozvati putem kartice sudionika na bočnoj traci ili slanjem ove poveznice!",
    "Share this link to invite others!" : "Podijelite ovu poveznicu kako biste pozvali ostale sudionike!",
    "Copy link" : "Kopiraj poveznicu",
    "You are not allowed to enable audio" : "Nije vam dopušteno omogućiti zvuk",
    "No audio. Click to select device" : "Nema zvuka. Kliknite za odabir uređaja",
    "Mute audio" : "Isključi zvuk",
    "Mute audio (M)" : "Isključi zvuk (M)",
    "Unmute audio" : "Uključi zvuk",
    "Unmute audio (M)" : "Uključi zvuk (M)",
    "None" : "Nema",
    "Select a microphone" : "Odaberite mikrofon",
    "Select a speaker" : "Odaberite zvučnik",
    "Microphone settings" : "Postavke mikrofona",
    "Check devices" : "Provjeri uređaje",
    "Access to camera was denied" : "Pristup kameri je odbijen",
    "Error while accessing camera: It is likely in use by another program" : "Pogreška pri pristupu kameri: vjerojatno je koristi drugi program",
    "Error while accessing camera" : "Došlo je do pogreške pri pristupanju kameri",
    "You have been muted by a moderator" : "Utišao vas je moderator",
    "Hide presenter video" : "Sakrij video prezentera",
    "You are not allowed to enable video" : "Nije vam dopušteno omogućiti videoprijenos",
    "No video. Click to select device" : "Nema videa. Kliknite za odabir uređaja",
    "Disable video" : "Onemogući videoprijenos",
    "Disable video (V)" : "Onemogući videoprijenos (V)",
    "Enable video" : "Omogući videoprijenos",
    "Enable video (V)" : "Omogući videoprijenos (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Omogući video – vaša će se veza kratko prekinuti pri prvom uključivanju videa",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Omogući videoprijenos (V) – veza će se nakratko prekinuti pri prvom omogućivanju videoprijenosa",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Omogući videoprijenos. Veza će se nakratko prekinuti pri prvom omogućivanju videoprijenosa",
    "Select a video device" : "Odaberite video uređaj",
    "Show presenter" : "Prikaži prezentera",
    "You" : "Vi",
    "Mute" : "Utišaj",
    "Muted" : "Isključeno",
    "Show screen" : "Prikaži zaslon",
    "Stop following" : "Prekini praćenje",
    "Connection could not be established …" : "Nije moguće uspostaviti vezu …",
    "Connection was lost and could not be re-established …" : "Veza je izgubljena i nije je moguće ponovno uspostaviti …",
    "Connection could not be established. Trying again …" : "Nije moguće uspostaviti vezu. Pokušavam ponovno …",
    "Connection lost. Trying to reconnect …" : "Veza je izgubljena. Pokušavam ponovno povezivanje …",
    "Connection problems …" : "Problemi s vezom …",
    "Collapse" : "Sakrij",
    "Expand" : "Proširi",
    "You need to be logged in to upload files" : "Morate biti prijavljeni kako biste otpremali datoteke",
    "Drop your files to upload" : "Ispustite datoteke za otpremu",
    "Conversation messages" : "Poruke razgovora",
    "Scroll to bottom" : "Pomakni se na dno",
    "Post message" : "Objavi poruku",
    "Federated conversation" : "Udruženi razgovor",
    "Public conversation" : "Javni razgovor",
    "Favorite" : "Favorit",
    "Banned users" : "Zabranjeni korisnici",
    "Manage the list of banned users in this conversation." : "Upravljajte popisom zabranjenih korisnika u ovom razgovoru.",
    "Manage bans" : "Upravljanje zabranama",
    "No banned users" : "Nema zabranjenih korisnika",
    "Banned by:" : "Zabranio:",
    "Date:" : "Datum:",
    "Note:" : "Napomena:",
    "Hide details" : "Sakrij pojedinosti",
    "Show details" : "Prikaži pojedinosti",
    "Unban" : "Ukloni zabranu",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Naslov i opis možete promijeniti u {linkstart}Kalendaru ↗{linkend}.",
    "Error while updating conversation name" : "Pogreška pri ažuriranju naziva razgovora",
    "Error while updating conversation description" : "Pogreška pri ažuriranju opisa razgovora",
    "Enter a name for this conversation" : "Unesite naziv za ovaj razgovor",
    "Edit conversation name" : "Uredi naziv razgovora",
    "Edit conversation description" : "Opis uređivanja razgovora",
    "Enter a description for this conversation" : "Unesite opis ovog razgovora",
    "Picture" : "Slika",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Sljedeći botovi mogu se omogućiti u ovom razgovoru. Obratite se administraciji da instalira više botova na ovom poslužitelju.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Na ovom poslužitelju nisu instalirani botovi. Obratite se administraciji da instalira botove na ovom poslužitelju.",
    "Disable" : "Onemogući",
    "Enable" : "Omogući",
    "Breakout rooms" : "Sobe za odvajanje",
    "Manage breakout rooms" : "Upravljanje sobama za odvajanje",
    "Set up breakout rooms for this conversation" : "Postavite sobe za odvajanje za ovaj razgovor",
    "Please select a valid PNG or JPG file" : "Odaberite valjanu PNG ili JPG datoteku",
    "Choose your conversation picture" : "Odaberite sliku razgovora",
    "Choose" : "Odaberite",
    "Error setting conversation picture" : "Pogreška pri postavljanju slike razgovora",
    "Could not set the conversation picture: {error}" : "Nije moguće postaviti sliku razgovora: {error}",
    "Error cropping conversation picture" : "Pogreška pri obrezivanju slike razgovora",
    "Error removing conversation picture" : "Pogreška pri uklanjanju slike razgovora",
    "Set emoji as conversation picture" : "Postavi emoji kao sliku razgovora",
    "Set background color for conversation picture" : "Postavi boju pozadine za sliku razgovora",
    "Upload conversation picture" : "Prenesi sliku razgovora",
    "Choose conversation picture from files" : "Odaberite sliku razgovora iz datoteka",
    "Remove conversation picture" : "Ukloni sliku razgovora",
    "The file must be a PNG or JPG" : "Datoteka mora biti PNG ili JPG",
    "Set picture" : "Postavi sliku",
    "Default permissions modified for {conversationName}" : "Izmijenjena su zadana dopuštenja za {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Nije moguće izmijeniti zadana dopuštenja za {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Uredite zadana dopuštenja za sudionike ovog razgovora. Ove postavke ne utječu na moderatore.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Svaki put kada se u ovom odjeljku izmijene dopuštenja, izgubit će se prilagođena dopuštenja koja su prethodno dodijeljena pojedinim sudionicima.",
    "All permissions" : "Sva dopuštenja",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Sudionici imaju dopuštenja za pokretanje poziva, pridruživanje pozivu, uključivanje zvuka i videa te dijeljenje zaslona.",
    "Restricted" : "Ograničeno",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Sudionici se mogu pridružiti pozivima, ali ne mogu uključiti zvuk ni video niti dijeliti zaslon dok im moderator ručno ne dodijeli dopuštenja.",
    "Advanced permissions" : "Napredna dopuštenja",
    "Edit permissions" : "Uredi dopuštenja",
    "Conversation settings" : "Postavke razgovora",
    "Basic Info" : "Osnovne informacije",
    "Personal" : "Osobno",
    "Moderation" : "Moderiranje",
    "Setup overview" : "Pregled postavljanja",
    "Live transcription" : "Pretvaranje u tekst uživo",
    "Live transcriptions app is not installed" : "Aplikacija za pretvaranje u tekst nije instaliranja",
    "Enable live transcription" : "Omogući pretvaranje u tekst uživo",
    "Breakout Rooms" : "Sobe za odvajanje",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Botovi",
    "Danger zone" : "Zona opasnosti",
    "Archive conversation" : "Arhiviraj razgovor",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Arhivirani razgovori zadano su skriveni s popisa razgovora. Ipak, i dalje će se pojaviti kada pretražujete naziv razgovora ili pristupite popisu arhiviranih razgovora.",
    "Do you really want to leave \"{displayName}\"?" : "Želite li zaista napustiti „{displayName}”?",
    "You can archive this conversation instead." : "Umjesto toga možete arhivirati ovaj razgovor.",
    "Leave conversation" : "Napusti razgovor",
    "You need to promote a new moderator before you can leave the conversation" : "Prije nego što možete napustiti razgovor, morate promovirati novog moderatora",
    "Delete conversation" : "Izbriši razgovor",
    "Do you really want to delete \"{displayName}\"?" : "Želite li zaista izbrisati „{displayName}“?",
    "Error while deleting conversation" : "Pogreška pri brisanju razgovora",
    "Delete all chat messages" : "Izbriši sve razmijenjene poruke",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Želite li zaista izbrisati sve poruke u „{displayName}“?",
    "Error while clearing chat history" : "Pogreška pri brisanju povijesti razmjene poruka",
    "Be careful, these actions cannot be undone." : "Pažljivo nastavite jer ove radnje nije moguće poništiti.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Nakon izlaska iz razgovora za ponovni pristup zatvorenom razgovoru potreban je poziv. Otvorenom razgovoru možete se ponovno pridružiti u bilo kojem trenutku.",
    "Permanently delete this conversation." : "Trajno izbrišite ovaj razgovor.",
    "Delete chat messages" : "Izbriši razmijenjene poruke",
    "Permanently delete all the messages in this conversation." : "Trajno izbrišite sve poruke u ovom razgovoru.",
    "Custom expiration time" : "Prilagođeno vrijeme isteka",
    "Message expiration disabled" : "Istjecanje poruka je onemogućeno",
    "Message expiration set: {duration}" : "Istjecanje poruka postavljeno: {duration}",
    "Error when trying to set message expiration" : "Pogreška pri postavljanju istjecanja poruka",
    "Message expiration" : "Istjecanje poruka",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Poruke u chatu mogu isteći nakon određenog vremena. Napomena: datoteke podijeljene u chatu neće biti obrisane vlasniku, ali se više neće dijeliti u razgovoru.",
    "Set message expiration" : "Postavi istjecanje poruka",
    "Current message expiration" : "Trenutačno istjecanje poruka",
    "Password copied to clipboard" : "Lozinka je kopirana u međuspremnik",
    "Password could not be copied" : "Lozinku nije moguće kopirati",
    "Guest access" : "Pristup gostiju",
    "Breakout rooms are not allowed in public conversations." : "Sobe za odvajanje nisu dopuštene u javnim razgovorima.",
    "Allow guests to join this conversation via link" : "Dopusti gostima pridruživanje ovom razgovoru putem poveznice",
    "Password protection" : "Zaštita zaporkom",
    "This conversation is password-protected. Guests need password to join" : "Ovaj razgovor je zaštićen lozinkom. Gosti trebaju lozinku za pridruživanje",
    "Password protection is needed for public conversations" : "Za javne razgovore potrebna je zaštita lozinkom",
    "Set a password" : "Postavi lozinku",
    "Change password" : "Promijeni lozinku",
    "Enter new password" : "Unesite novu lozinku",
    "Save password" : "Spremi zaporku",
    "Copy password" : "Kopiraj lozinku",
    "Guests are allowed to join this conversation via link" : "Gostima je dopušteno pridružiti se ovom razgovoru putem poveznice",
    "Guests are not allowed to join this conversation" : "Gostima nije dopušteno pridružiti se ovom razgovoru",
    "Resend invitations" : "Ponovno pošalji pozivnice",
    "This conversation is open to both registered users and users created with the Guests app" : "Ovaj je razgovor otvoren i za registrirane korisnike i za korisnike stvorene aplikacijom Gosti",
    "This conversation is open to registered users" : "Ovaj je razgovor otvoren za registrirane korisnike",
    "This conversation is limited to the current participants" : "Ovaj je razgovor ograničen na trenutačne sudionike",
    "You opened the conversation to both registered users and users created with the Guests app" : "Otvorili ste razgovor i za registrirane korisnike i za korisnike stvorene aplikacijom Gosti",
    "Error occurred when opening or limiting the conversation" : "Došlo je do pogreške pri otvaranju ili ograničavanju razgovora",
    "Open conversation to registered users, showing it in search results" : "Otvori razgovor za registrirane korisnike, uz prikaz u rezultatima pretraživanja",
    "Also open to users created with the Guests app" : "Također otvoreno za korisnike stvorene aplikacijom Gosti",
    "Open conversation" : "Otvori razgovor",
    "Set language spoken in calls" : "Postavi jezik koji se govori u pozivima",
    "Languages could not be loaded" : "Nije moguće učitati jezike",
    "Loading languages …" : "Učitavanje jezika …",
    "Invalid language" : "Nevažeći jezik",
    "Default language (English)" : "Zadani jezik (engleski)",
    "Default live transcription language set" : "Zadani jezik pretvaranja u tekst uživo je postavljen",
    "Live transcription language set: {languageName}" : "Jezik pretvaranja u tekst uživo postavljen: {languageName}",
    "Error when trying to set live transcription language" : "Pogreška pri postavljanju jezika pretvaranja u tekst uživo",
    "Start time: {date}" : "Vrijeme početka: {date}",
    "Start time has been updated" : "Vrijeme početka je ažurirano",
    "Error occurred while updating start time" : "Došlo je do pogreške pri ažuriranju vremena početka",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Omogućavanje predvorja uklonit će ne-moderatore iz poziva koji je u tijeku.",
    "Enable lobby, restricting the conversation to moderators" : "Omogući predvorje, ograniči razgovor na moderatore",
    "Meeting start time" : "Vrijeme početka sastanka",
    "Start time (optional)" : "Vrijeme početka (neobvezno)",
    "Import email participants" : "Uvezi sudionike putem e-pošte",
    "You can import a list of email participants from a CSV file." : "Možete uvesti popis sudionika putem e-pošte iz CSV datoteke.",
    "Poll drafts" : "Skice anketa",
    "Browse poll drafts" : "Pregledaj skice anketa",
    "Error occurred when locking the conversation" : "Došlo je do pogreške pri zaključavanju razgovora",
    "Error occurred when unlocking the conversation" : "Došlo je do pogreške pri otključavanju razgovora",
    "Lock conversation" : "Zaključaj razgovor",
    "This will also terminate the ongoing call." : "Ovime ćete također prekinuti poziv.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Zaključajte razgovor kako biste spriječili bilo koga da objavljuje poruke ili pokreće pozive",
    "Edit" : "Uredi",
    "More information" : "Više informacija",
    "Delete" : "Izbriši",
    "Add new bridged channel to current conversation" : "Dodaj novi povezani kanal u trenutačni razgovor",
    "unknown state" : "nepoznato stanje",
    "running" : "radi",
    "not running, check Matterbridge log" : "nije pokrenuto, provjeri zapisnik Matterbridgea",
    "not running" : "ne radi",
    "Bridge saved" : "Veza spašena",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Zahvaljujući aplikaciji Matterbridge možete povezati kanale iz različitih sustava razmjene kratkih poruka.",
    "More info on Matterbridge" : "Više informacija o Matterbridgeu",
    "Messaging systems" : "Sustavi za razmjenu poruka",
    "Enable bridge" : "Omogući povezivanje",
    "Show Matterbridge log" : "Prikaži zapisnik Matterbridgea",
    "Log content" : "Sadržaj zapisa",
    "Only moderators are allowed to mention @all" : "Samo moderatori smiju spominjati @all",
    "All participants are allowed to mention @all" : "Svi sudionici smiju spominjati @all",
    "Participants are now allowed to mention @all." : "Sudionicima je sada dopušteno spominjati @all.",
    "Mentioning @all has been limited to moderators." : "Spominjanje @all ograničeno je na moderatore.",
    "Allow participants to mention @all" : "Dopusti sudionicima spominjanje @all",
    "Mention permissions" : "Dopuštenja za spominjanje",
    "Notifications" : "Obavijesti",
    "Notify about calls in this conversation" : "Obavijesti o pozivima u ovom razgovoru",
    "Important conversation" : "Važan razgovor",
    "\"Do not disturb\" user status is ignored for important conversations" : "Status korisnika „Ne ometaj” zanemaruje se za važne razgovore",
    "Sensitive conversation" : "Osjetljiv razgovor",
    "Message preview will be disabled in conversation list and notifications" : "Pregled poruke bit će onemogućen na popisu razgovora i u obavijestima",
    "Recording consent is required for calls in this conversation" : "Privola za snimanje potrebna je za pozive u ovom razgovoru",
    "Recording consent is not required for calls in this conversation" : "Privola za snimanje nije potrebna za pozive u ovom razgovoru",
    "Recording consent requirement was updated" : "Zahtjev za privolu za snimanje je ažuriran",
    "Error occurred while updating recording consent" : "Došlo je do pogreške pri ažuriranju privole za snimanje",
    "Recording Consent" : "Privola za snimanje",
    "Recording consent cannot be changed once a call or breakout session has started." : "Privola za snimanje ne može se mijenjati nakon što je poziv ili sesija soba za odvajanje započela.",
    "Require recording consent before joining call in this conversation" : "Zahtijevaj privolu za snimanje prije pridruživanja pozivu u ovom razgovoru",
    "Recording consent is required for all calls" : "Privola za snimanje potrebna je za sve pozive",
    "SIP dial-in is now possible without PIN requirement" : "SIP biranje prema unutra sada je moguće bez potrebe za PIN-om",
    "SIP dial-in is now enabled" : "Povezivanje putem SIP-a je omogućeno",
    "SIP dial-in is now disabled" : "Povezivanje putem SIP-a je onemogućeno",
    "Error occurred when enabling SIP dial-in" : "Došlo je do pogreške pri omogućavanju povezivanja putem SIP-a",
    "Error occurred when disabling SIP dial-in" : "Došlo je do pogreške pri onemogućavanju povezivanja putem SIP-a",
    "Phone and SIP dial-in" : "Telefonsko i SIP biranje prema unutra",
    "Enable phone and SIP dial-in" : "Omogući telefonsko i SIP biranje prema unutra",
    "Allow to dial-in without a PIN" : "Dopusti biranje prema unutra bez PIN-a",
    "Ongoing" : "U tijeku",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n osoba je prihvatila","%n osobe su prihvatile","%n osoba je prihvatilo"],
    "_%n person declined_::_%n people declined_" : ["%n osoba je odbila","%n osobe su odbile","%n osoba je odbilo"],
    "_and %n other attachment_::_and %n other attachments_" : ["i još %n drugi privitak","i još %n druga privitka","i još %n drugih privitaka"],
    "With {displayName}" : "S {displayName}",
    "In {conversation}" : "U {conversation}",
    "View attachment" : "Prikaži privitak",
    "Join" : "Pridruži se",
    "View conversation" : "Prikaži razgovor",
    "View event on Calendar" : "Prikaži događaj u Kalendaru",
    "Error while creating the conversation" : "Pogreška pri stvaranju razgovora",
    "Hello, {displayName}" : "Pozdrav, {displayName}",
    "Start meeting now" : "Pokreni sastanak sada",
    "Give your meeting a title" : "Dajte sastanku naslov",
    "Create and copy link" : "Stvori i kopiraj poveznicu",
    "Create a new conversation" : "Stvori novi razgovor",
    "Join open conversations" : "Pridruži se otvorenim razgovorima",
    "Call a phone number" : "Nazovi telefonski broj",
    "Scroll backward" : "Pomakni unatrag",
    "Scroll forward" : "Pomakni naprijed",
    "Schedule meetings" : "Zakaži sastanke",
    "You don't have any upcoming meetings" : "Nemate nadolazećih sastanaka",
    "Open calendar" : "Otvori kalendar",
    "Unread mentions" : "Nepročitana spominjanja",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Poruke u kojima ste spomenuti prikazat će se ovdje. Osobe možete spomenuti upisivanjem @ nakon čega slijedi njihovo ime",
    "Upcoming reminders" : "Nadolazeći podsjetnici",
    "Message reminders" : "Podsjetnici poruka",
    "Set a reminder on a message to be notified" : "Postavite podsjetnik na poruku kako biste dobili obavijest",
    "Start a group conversation" : "Pokreni grupni razgovor",
    "Create conversation" : "Stvori razgovor",
    "Enter your name" : "Unesite svoje ime",
    "Submit name and join" : "Pošalji ime i pridruži se",
    "Do you already have an account?" : "Imate li već račun?",
    "Log in" : "Prijavite se",
    "Error while verifying uploaded file" : "Pogreška pri provjeri prenesene datoteke",
    "Uploaded file is verified" : "Prenesena datoteka je provjerena",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Format sadržaja je CSV (vrijednosti odvojene zarezom):<br/>- Redak zaglavlja je obvezan i mora odgovarati <samp>\"name\",\"email\"</samp> ili samo <samp>\"email\"</samp><br/>- Jedan unos po retku (npr. <samp>\"John Doe\",\"john@example.tld\"</samp>)",
    "Participants added successfully" : "Sudionici su uspješno dodani",
    "Error while adding participants" : "Pogreška pri dodavanju sudionika",
    "Import a file" : "Uvezi datoteku",
    "Browse" : "Pregledaj",
    "Verifying uploaded file …" : "Provjera prenesene datoteke …",
    "This might take a moment" : "To može potrajati trenutak",
    "Send invitations" : "Pošalji pozivnice",
    "_%n invalid email_::_%n invalid emails_" : ["%n neispravna adresa e-pošte","%n neispravne adrese e-pošte","%n neispravnih adresa e-pošte"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n adresa e-pošte već je uvezena ili je duplikat","%n adrese e-pošte već su uvezene ili su duplikati","%n adresa e-pošte već je uvezeno ili su duplikati"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n pozivnica se može poslati","%n pozivnice se mogu poslati","%n pozivnica se može poslati"],
    "An error occurred while calling a phone number" : "Došlo je do pogreške pri pozivanju telefonskog broja",
    "Phone number could not be called: {error}" : "Telefonski broj nije moguće pozvati: {error}",
    "Phone number could not be called" : "Telefonski broj nije moguće pozvati",
    "Search participants or phone numbers" : "Pretraži sudionike ili telefonske brojeve",
    "Creating the conversation …" : "Stvaranje razgovora …",
    "Mark as read" : "Označi kao pročitano",
    "Mark as unread" : "Označi kao nepročitano",
    "Remove from favorites" : "Ukloni iz favorita",
    "Add to favorites" : "Dodaj u favorite",
    "Unarchive conversation" : "Dearhiviraj razgovor",
    "Ignore \"Do not disturb\"" : "Zanemari \"Ne ometaj\"",
    "You need to promote a new moderator before you can leave the conversation." : "Morate odabrati novog moderatora prije nego što napustite razgovor.",
    "New tag" : "Nova oznaka",
    "Tag name" : "Naziv oznake",
    "Conversation actions" : "Radnje razgovora",
    "Tags" : "Oznake",
    "Notify about calls" : "Obavijesti o pozivima",
    "Hide message text" : "Sakrij tekst poruke",
    "Rename tag" : "Preimenuj oznaku",
    "Delete tag" : "Izbriši oznaku",
    "Move up" : "Premjesti gore",
    "Move down" : "Premjesti dolje",
    "Pending invitations" : "Pozivnice na čekanju",
    "Join conversations from other servers" : "Pridruži se razgovorima s drugih poslužitelja",
    "From {user} at {remoteServer}" : "Od {user} na {remoteServer}",
    "Decline invitation" : "Odbij pozivnicu",
    "Accept invitation" : "Prihvati pozivnicu",
    "No pending invitations" : "Nema pozivnica na čekanju",
    "Home" : "Početna",
    "Unread" : "Nepročitano",
    "Mentions" : "Spominjanja",
    "Meetings" : "Sastanci",
    "Sort conversations" : "Sortiraj razgovore",
    "By recent activity" : "Prema nedavnoj aktivnosti",
    "Alphabetically" : "Abecedno",
    "Do not group by type" : "Ne grupiraj po tipu",
    "Show private ones first" : "Prvo prikaži privatne",
    "Show group ones first" : "Prvo prikaži grupne",
    "No followed threads" : "Nema praćenih niti",
    "No matches found" : "Nema pronađenih podudaranja",
    "No conversations found" : "Nije pronađen nijedan razgovor",
    "You have no archived conversations." : "Nemate arhiviranih razgovora.",
    "Subscribe to an existing thread or start your own." : "Pretplatite se na postojeću nit ili pokrenite vlastitu.",
    "You have no unread mentions." : "Nemate nepročitanih spominjanja.",
    "You have no unread messages." : "Nemate nepročitanih poruka.",
    "An error occurred while performing the search" : "Došlo je do pogreške pri pretraživanju",
    "Conversation list" : "Popis razgovora",
    "Filter conversations by" : "Filtriraj razgovore prema",
    "Unread messages" : "Nepročitane poruke",
    "Meeting conversations" : "Razgovori u sastancima",
    "Clear filters" : "Očisti filtre",
    "New personal note" : "Nova osobna bilješka",
    "SIP backend is not installed" : "SIP pozadinski sustav nije instaliran",
    "Back to conversations" : "Natrag na razgovore",
    "Threads" : "Niti",
    "Archived conversations" : "Arhivirani razgovori",
    "Clear filter" : "Ukloni filtar",
    "Show more threads" : "Prikaži više niti",
    "App settings" : "Postavke aplikacije",
    "Users" : "Korisnici",
    "Groups" : "Grupe",
    "Teams" : "Timovi",
    "Federated users" : "Udruženi korisnici",
    "New private conversation" : "Novi privatni razgovor",
    "Other sources" : "Drugi izvori",
    "Open conversations" : "Otvori razgovore",
    "No search results" : "Nema rezultata pretraživanja",
    "Users, groups and teams" : "Korisnici, grupe i timovi",
    "Users and groups" : "Korisnici i grupe",
    "Users and teams" : "Korisnici i timovi",
    "Groups and teams" : "Grupe i timovi",
    "New group conversation" : "Novi grupni razgovor",
    "The meeting will start soon" : "Sastanak počinje uskoro",
    "This meeting is scheduled for {startTime}" : "Sastanak počinje u {startTime}",
    "You are currently waiting in the lobby" : "Trenutno čekate u predvorju",
    "Enable noise suppression" : "Omogući uklanjanje šuma",
    "Reduce background noises for better voice quality" : "Smanjite pozadinske šumove za bolju kvalitetu glasa",
    "Advanced" : "Napredno",
    "Enable echo cancellation" : "Omogući poništavanje jeke",
    "Minimize echo effect from own surrounding" : "Smanjite učinak jeke iz okoline",
    "Enable auto gain control" : "Omogući automatsku kontrolu pojačanja",
    "Dynamically adjust microphone volume for consistent level" : "Dinamički prilagođava glasnoću mikrofona za ujednačenu razinu",
    "Select microphone" : "Odaberi mikrofon",
    "No microphone available" : "Nema dostupnih mikrofona",
    "Select speaker" : "Odaberite zvučnik",
    "No speaker available" : "Nema dostupnog zvučnika",
    "Select camera" : "Odaberi kameru",
    "No camera available" : "Nema dostupnih kamera",
    "Select a device" : "Odaberi uređaj",
    "Playing …" : "Reprodukcija …",
    "Test speakers" : "Testiraj zvučnike",
    "Test" : "Ispitivanje",
    "Devices" : "Uređaji",
    "Backgrounds" : "Pozadine",
    "No audio" : "Nema zvuka",
    "No camera" : "Nema kamere",
    "Display video as you will see it (mirrored)" : "Prikaži video kako ćete ga vi vidjeti (zrcaljeno)",
    "Display video as others will see it" : "Prikaži video kako će ga drugi vidjeti",
    "Calls are not supported in your browser" : "Vaš preglednik ne podržava pozive",
    "Access to microphone is only possible with HTTPS" : "Pristup mikrofonu moguć je samo putem HTTPS-a",
    "Access to microphone was denied" : "Pristup mikrofonu je odbijen",
    "Error while accessing microphone" : "Došlo je do pogreške pri pristupanju mikrofonu",
    "Access to camera is only possible with HTTPS" : "Pristup kameri moguć je samo putem HTTPS-a",
    "The call is being recorded." : "Poziv se snima.",
    "The call might be recorded." : "Poziv se možda snima.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Snimka može uključivati vaš glas, video s kamere i dijeljenje zaslona. Prije pridruživanja pozivu potrebna je vaša privola.",
    "Give consent to the recording of this call" : "Dajem privolu za snimanje ovog poziva",
    "Show more info" : "Prikaži više informacija",
    "Audio is not available" : "Zvuk nije dostupan",
    "Video is not available" : "Video nije dostupan",
    "Start recording immediately with the call" : "Započni snimanje odmah s pozivom",
    "Recording backend is not installed" : "Pozadinski sustav za snimanje nije instaliran",
    "Notify all participants about this call" : "Obavijesti sve sudionike o ovom pozivu",
    "Apply settings" : "Primijeni postavke",
    "Select virtual office background" : "Odaberite virtualnu uredsku pozadinu",
    "Select virtual home background" : "Odaberite virtualnu kućnu pozadinu",
    "Select virtual abstract background" : "Odaberite virtualnu apstraktnu pozadinu",
    "Select virtual beach background" : "Odaberite virtualnu pozadinu plaže",
    "Select virtual park background" : "Odaberite virtualnu pozadinu parka",
    "Select virtual theater background" : "Odaberite virtualnu pozadinu kazališta",
    "Select virtual library background" : "Odaberite virtualnu pozadinu knjižnice",
    "Select virtual space station background" : "Odaberite virtualnu pozadinu svemirske postaje",
    "Error while uploading the file" : "Pogreška pri prijenosu datoteke",
    "Select a file" : "Odaberite datoteku",
    "Invalid path selected" : "Odabran nevažeći put",
    "Select virtual background from file {fileName}" : "Odaberite virtualnu pozadinu iz datoteke {fileName}",
    "Blur" : "Zamućenje",
    "Upload" : "Učitaj",
    "Files" : "Datoteke",
    "(editing)" : "(uređivanje)",
    "(edited)" : "(uređeno)",
    "The message has expired or has been deleted" : "Poruka je istekla ili je obrisana",
    "Cancel quote" : "Odustani od citiranja",
    "24 hours" : "24 sata",
    "7 days" : "7 dana",
    "30 days" : "30 dana",
    "Until unpin" : "Do otkvačivanja",
    "Clear reminder – {timeLocale}" : "Ukloni podsjetnik – {timeLocale}",
    "Edited by {actor}" : "Uredio {actor}",
    "Pinned by you" : "Prikvačili ste",
    "Pinned by {actor}" : "Prikvačio {actor}",
    "Until {absoluteDate}" : "Do {absoluteDate}",
    "Message text copied to clipboard" : "Tekst poruke kopiran je u međuspremnik",
    "Message text could not be copied" : "Tekst poruke nije moguće kopirati",
    "Message forwarded to \"Note to self\"" : "Poruka je proslijeđena u \"Bilješka za sebe\"",
    "Error while forwarding message to \"Note to self\"" : "Pogreška pri prosljeđivanju poruke u \"Bilješka za sebe\"",
    "A reminder was successfully removed" : "Podsjetnik je uspješno uklonjen",
    "Error occurred when removing a reminder" : "Došlo je do pogreške pri uklanjanju podsjetnika",
    "A reminder was successfully set at {datetime}" : "Podsjetnik je uspješno postavljen za {datetime}",
    "Error occurred when creating a reminder" : "Došlo je do pogreške pri stvaranju podsjetnika",
    "Add a reaction to this message" : "Dodaj reakciju na ovu poruku",
    "Reply" : "Odgovori",
    "More actions" : "Dodatne radnje",
    "Set reminder" : "Postavi podsjetnik",
    "Pin message" : "Prikvači poruku",
    "Unpin message" : "Otkvači poruku",
    "Reply privately" : "Odgovori privatno",
    "Edit message" : "Uredi poruku",
    "Copy message" : "Kopiraj poruku",
    "Copy message link" : "Kopiraj poveznicu poruke",
    "Go to file" : "Idi na datoteku",
    "Download file" : "Preuzmi datoteku",
    "Go to thread" : "Idi na nit",
    "Edit thread details" : "Uredi detalje niti",
    "Forward message" : "Proslijedi poruku",
    "Translate" : "Prevedi",
    "Set custom reminder" : "Postavi prilagođeni podsjetnik",
    "Keep pinned for" : "Zadrži prikvačeno",
    "Set custom period" : "Postavi prilagođeno razdoblje",
    "Close reactions menu" : "Zatvori izbornik reakcija",
    "React with {emoji}" : "Reagiraj s {emoji}",
    "React with another emoji" : "Reagiraj drugim emojijem",
    "Choose a conversation to forward the selected message." : "Odaberite razgovor u koji ćete proslijediti odabranu poruku.",
    "Error while forwarding message" : "Pogreška pri prosljeđivanju poruke",
    "The message has been forwarded to {selectedConversationName}" : "Poruka je proslijeđena u {selectedConversationName}",
    "Dismiss" : "Zanemari",
    "Go to conversation" : "Idi na razgovor",
    "The message could not be translated" : "Poruku nije moguće prevesti",
    "Translation copied to clipboard" : "Prijevod je kopiran u međuspremnik",
    "Translation could not be copied" : "Prijevod nije moguće kopirati",
    "Translate message" : "Prevedi poruku",
    "Source language to translate from" : "Izvorni jezik za prijevod",
    "Translate from" : "Prevedi s",
    "Target language to translate into" : "Ciljni jezik prijevoda",
    "Translate to" : "Prevedi na",
    "Translating" : "Prevođenje",
    "Copy translated text" : "Kopiraj prevedeni tekst",
    "Error when scheduling the message" : "Pogreška pri zakazivanju poruke",
    "Reschedule" : "Ponovno zakaži",
    "Send now" : "Pošalji sada",
    "Choose a time" : "Odaberite vrijeme",
    "Send at custom time" : "Pošalji u prilagođeno vrijeme",
    "Will be sent without notification" : "Bit će poslano bez obavijesti",
    "Message read by everyone who shares their reading status" : "Poruku je pročitao svatko tko dijeli status čitanja",
    "Message sent" : "Poruka poslana",
    "Sent without notification" : "Poslano bez obavijesti",
    "Deleting message" : "Brisanje poruke",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Poruka je uspješno obrisana, ali je konfiguriran bot ili Matterbridge pa je poruka možda već proslijeđena drugim uslugama",
    "Message deleted successfully" : "Poruka je uspješno izbrisana",
    "Message could not be deleted because it is too old" : "Poruku nije moguće izbrisati jer je prestara",
    "Only normal chat messages can be deleted" : "Mogu se izbrisati samo uobičajene razmijenjene poruke",
    "An error occurred while deleting the message" : "Došlo je do pogreške pri brisanju poruke",
    "Pinned" : "Prikvačeno",
    "Your browser does not support playing audio files" : "Vaš preglednik ne podržava reprodukciju zvučnih datoteka",
    "Contact" : "Kontakt",
    "{stack} in {board}" : "{stack} u {board}",
    "Deck Card" : "Deck kartica",
    "Remove {fileName}" : "Ukloni {fileName}",
    "Open this location in OpenStreetMap" : "Otvorite ovu lokaciju u aplikaciji OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n odgovor","%n odgovora","%n odgovora"],
    "Sending message" : "Slanje poruke",
    "Failed to send the message. Click to try again" : "Slanje poruke nije uspjelo. Kliknite kako biste ponovno pokušali",
    "Not enough free space to upload file" : "Nema dovoljno slobodnog prostora za otpremanje datoteke",
    "You cannot send messages to this conversation at the moment" : "Trenutno ne možete slati poruke u ovaj razgovor",
    "Could not update the message" : "Nije moguće ažurirati poruku",
    "Reply to thread \"{threadTitle}\"" : "Odgovori u niti \"{threadTitle}\"",
    "_You voted • %n vote_::_You voted • %n votes_" : ["Glasali ste • %n glas","Glasali ste • %n glasa","Glasali ste • %n glasova"],
    "You voted" : "Glasali ste",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["Glasajte • %n glas","Glasajte • %n glasa","Glasajte • %n glasova"],
    "Click to vote" : "Klikni za glasanje",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Skica ankete • %n opcija","Skica ankete • %n opcije","Skica ankete • %n opcija"],
    "_%n vote_::_%n votes_" : ["%n glas","%n glasa","%n glasova"],
    "Edit poll draft" : "Uredi skicu ankete",
    "Delete poll draft" : "Izbriši skicu ankete",
    "Open poll" : "Otvorena anketa",
    "Closed poll" : "Zatvorena anketa",
    "See results" : "Prikaži rezultate",
    "Reactions" : "Reakcije",
    "No permission to post reactions in this conversation" : "Nemate dopuštenje za objavljivanje reakcija u ovom razgovoru",
    "and {participant}" : "i {participant}",
    "_and %n other participant_::_and %n other participants_" : ["i još %n drugi sudionik","i još %n druga sudionika","i još %n drugih sudionika"],
    "Show all reactions" : "Prikaži sve reakcije",
    "Add more reactions" : "Dodaj još reakcija",
    "Show or collapse system messages" : "Prikaži ili sažmi sistemske poruke",
    "No messages" : "Nema poruka",
    "All messages have expired or have been deleted." : "Sve poruke su istekle ili su obrisane.",
    "Generate summary with AI" : "Generiraj sažetak pomoću umjetne inteligencije",
    "{author} (pinned by you)" : "{author} (prikvačeno od vas)",
    "{author} (pinned by {actor})" : "{author} (prikvačio {actor})",
    "Unpin" : "Otkvači",
    "Cancel search" : "Odustani od pretraživanja",
    "Add a phone number" : "Dodaj telefonski broj",
    "Error: A password is required to create the conversation." : "Pogreška: Za stvaranje razgovora potrebna je lozinka.",
    "All set, the conversation \"{conversationName}\" was created." : "Sve je spremno, razgovor \"{conversationName}\" je stvoren.",
    "Create a new group conversation" : "Stvori novi grupni razgovor",
    "Add participants" : "Dodaj sudionike",
    "Maximum length exceeded ({maxlength} characters)" : "Prekoračena je maksimalna duljina ({maxlength} znakova)",
    "Conversation visibility" : "Vidljivost razgovora",
    "Allow guests to join via link" : "Dopusti pridruživanje gostiju putem pozivnice",
    "Enter password" : "Unesi zaporku",
    "This conversation has been locked" : "Ovaj je razgovor zaključan",
    "No permission to post messages in this conversation" : "Nije dopušteno objavljivanje poruka u ovom razgovoru",
    "Joining conversation …" : "Pridruživanje razgovoru...",
    "Write a message without notification" : "Napiši poruku bez obavijesti",
    "Create a thread silently" : "Stvori nit tiho",
    "Create a thread" : "Stvori nit",
    "Send message silently" : "Pošalji poruku tiho",
    "Send message" : "Pošalji poruku",
    "Send without notification" : "Pošalji bez obavijesti",
    "The participant will not be notified about new messages" : "Sudionik neće biti obaviješten o novim porukama",
    "Participants will not be notified about new messages" : "Sudionici neće biti obaviješteni o novim porukama",
    "Message will be sent {datetimeString}" : "Poruka će biti poslana {datetimeString}",
    "Thread title is required" : "Naslov niti je obvezan",
    "Message text is required" : "Tekst poruke je obvezan",
    "The message could not be edited" : "Poruku nije moguće urediti",
    "File to share" : "Datoteka za dijeljenje",
    "File upload is not available in this conversation" : "Prijenos datoteka nije dostupan u ovom razgovoru",
    "Message was successfully scheduled" : "Poruka je uspješno zakazana",
    "Add emoji" : "Dodaj emoji",
    "Adding a mention will only notify users who did not read the message." : "Dodavanje spominjanja obavijestit će samo korisnike koji nisu pročitali poruku.",
    "Thread title" : "Naslov niti",
    "Send later" : "Pošalji kasnije",
    "Show scheduled messages" : "Prikaži zakazane poruke",
    "Cancel editing" : "Odustani od uređivanja",
    "Schedule message" : "Zakaži poruku",
    "{user} is out of office and might not respond." : "{user} je izvan ureda i možda neće odgovoriti.",
    "Absence period: {startDate} - {endDate}" : "Razdoblje odsutnosti: {startDate} – {endDate}",
    "Replacement:" : "Zamjena:",
    "Share from {nextcloud}" : "Dijeli iz {nextcloud}",
    "Share from Files" : "Dijeli iz datoteka",
    "Share files to the conversation" : "Dijeli datoteke u razgovor",
    "Upload from device" : "Prenesi s uređaja",
    "Create new poll" : "Stvori novu anketu",
    "Smart picker" : "Pametni odabir",
    "Record voice message" : "Snimi glasovnu poruku",
    "End recording and send" : "Završi snimak i pošalji",
    "Dismiss recording" : "Odbaci snimak",
    "Access to the microphone was denied" : "Pristup mikrofonu je odbijen",
    "Microphone either not available or disabled in settings" : "Mikrofon nije raspoloživ ili je onemogućen u postavkama",
    "Error while recording audio" : "Pogreška tijekom snimanja zvuka",
    "Voice message {time} ({conversation})" : "Glasovna poruka {time} ({conversation})",
    "Generating summary of unread messages …" : "Generiranje sažetka nepročitanih poruka …",
    "Summary is AI generated and might contain mistakes" : "Sažetak je generirala umjetna inteligencija i može sadržavati pogreške",
    "Error occurred during a summary generation" : "Došlo je do pogreške tijekom generiranja sažetka",
    "New file" : "Nova datoteka",
    "Blank" : "Prazno",
    "Error while creating file" : "Pogreška pri stvaranju datoteke",
    "Create and share a new file" : "Stvori i podijeli novu datoteku",
    "Name of the new file" : "Naziv nove datoteke",
    "Create file" : "Stvori datoteku",
    "Someone is typing …" : "Netko piše …",
    "{user1} is typing …" : "{user1} piše …",
    "{user1} and {user2} are typing …" : "{user1} i {user2} pišu …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} i {user3} pišu …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} i još %n osoba pišu …","{user1}, {user2}, {user3} i još %n osobe pišu …","{user1}, {user2}, {user3} i još %n osoba pišu …"],
    "Add more files" : "Dodaj više datoteka",
    "Send" : "Pošalji",
    "In this conversation <strong>{user}</strong> can:" : "U ovom razgovoru <strong>{user}</strong> može:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Uredite zadana dopuštenja za sudionike u <strong>{conversationName}</strong>",
    "Start a call" : "Uputi poziv",
    "Skip the lobby" : "Preskoči predvorje",
    "Can post messages" : "Može slati poruke",
    "Can post messages and reactions" : "Može slati poruke i reakcije",
    "Can add reactions" : "Može dodavati reakcije",
    "Enable the microphone" : "Omogućite mikrofon",
    "Enable the camera" : "Omogućite kameru",
    "Share the screen" : "Dijelite zaslon",
    "Update permissions" : "Ažuriraj dopuštenja",
    "Updating permissions" : "Ažuriranje dopuštenja",
    "No poll drafts" : "Nema skica anketa",
    "There is no poll drafts yet saved for this conversation" : "Još nema spremljenih skica anketa za ovaj razgovor",
    "Create poll in {name}" : "Stvori anketu u {name}",
    "Create poll" : "Stvori anketu",
    "Error while importing poll" : "Pogreška pri uvozu ankete",
    "Question" : "Pitanje",
    "Ask a question" : "Postavite pitanje",
    "Import draft from file" : "Uvezi skicu iz datoteke",
    "Answers" : "Odgovori",
    "Answer {option}" : "Odgovor {option}",
    "Delete poll option" : "Izbriši opciju ankete",
    "Add answer" : "Dodaj odgovor",
    "Settings" : "Postavke",
    "Anonymous poll" : "Anonimna anketa",
    "Multiple answers" : "Više odgovora",
    "Save as draft" : "Spremi kao skicu",
    "Export draft to file" : "Izvezi skicu u datoteku",
    "_Final results • %n vote_::_Final results • %n votes_" : ["Konačni rezultati • %n glas","Konačni rezultati • %n glasa","Konačni rezultati • %n glasova"],
    "Your vote is anonymous" : "Vaš glas je anoniman",
    "You voted for this option" : "Glasali ste za ovu opciju",
    "End poll" : "Završi anketu",
    "Change your vote" : "Promijeni glas",
    "Withdraw vote" : "Povuci glas",
    "Results" : "Rezultati",
    "Voted participants" : "Sudionici koji su glasali",
    "Send a message to \"{roomName}\"" : "Pošalji poruku u \"{roomName}\"",
    "Hide list of participants" : "Sakrij popis sudionika",
    "Show list of participants" : "Prikaži popis sudionika",
    "Assistance requested in {roomName}" : "Zatražena je pomoć u {roomName}",
    "The message was sent to \"{roomName}\"" : "Poruka je poslana u \"{roomName}\"",
    "Dismiss request for assistance" : "Odbaci zahtjev za pomoć",
    "Send message to room" : "Pošalji poruku u sobu",
    "Back to main room" : "Natrag u glavnu sobu",
    "Back to your room" : "Natrag u vašu sobu",
    "Message all rooms" : "Poruka svim sobama",
    "Start session" : "Pokreni sesiju",
    "Start a call before you start a breakout room session" : "Pokrenite poziv prije nego što pokrenete sesiju soba za odvajanje",
    "Stop session" : "Zaustavi sesiju",
    "The message was sent to all breakout rooms" : "Poruka je poslana u sve sobe za odvajanje",
    "Send a message to all breakout rooms" : "Pošalji poruku u sve sobe za odvajanje",
    "Breakout rooms are not started" : "Sobe za odvajanje nisu pokrenute",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Pozivi bez visokoučinkovitog pozadinskog sustava mogu uzrokovati probleme s povezivošću i veliko opterećenje uređaja. {linkstart}Saznajte više{linkend}",
    "Talk setup incomplete" : "Postavljanje Talka nije dovršeno",
    "Disable lobby" : "Onemogući predvorje",
    "Settings for participant \"{user}\"" : "Postavke sudionika „{user}”",
    "Participant \"{user}\"" : "Sudionik „{user}”",
    "moderator" : "moderator",
    "bot" : "bot",
    "guest" : "gost",
    "Ringing …" : "Zvoni …",
    "Call rejected" : "Poziv je odbijen",
    "{time} talking …" : "{time} razgovor …",
    "{time} talking time" : "{time} vrijeme razgovora",
    "Raised their hand" : "Podigli ruke",
    "Joined with video" : "Pridružen putem videoveze",
    "Joined via phone" : "Pridružen putem telefona",
    "Joined with audio" : "Pridružen putem audioveze",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Tekst mora imati najviše {maxLength} znakova. Vaš trenutačni tekst ima {charactersCount} znakova.",
    "Remove group and members" : "Ukloni grupu i članove",
    "Remove team and members" : "Ukloni tim i članove",
    "Remove participant" : "Ukloni sudionika",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Želite li zaista ukloniti grupu \"{displayName}\" i njezine članove iz ovog razgovora?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Želite li zaista ukloniti tim \"{displayName}\" i njegove članove iz ovog razgovora?",
    "Do you really want to remove {displayName} from this conversation?" : "Želite li zaista ukloniti {displayName} iz ovog razgovora?",
    "Notification was sent to {displayName}" : "Obavijest je poslana korisniku {displayName}",
    "Could not send notification to {displayName}" : "Nije moguće poslati obavijest korisniku {displayName}",
    "Permissions granted to {displayName}" : "Dopuštenja dodijeljena {displayName}",
    "Could not modify permissions for {displayName}" : "Nije moguće izmijeniti dopuštenja za {displayName}",
    "Permissions removed for {displayName}" : "Uklonjena su dopuštenja za {displayName}",
    "Permissions set to default for {displayName}" : "Dopuštenja su vraćena na zadana za {displayName}",
    "Phone number could not be hung up" : "Telefonski broj nije moguće prekinuti",
    "Phone number could not be put on hold" : "Telefonski broj nije moguće staviti na čekanje",
    "Phone number could not be muted" : "Telefonski broj nije moguće utišati",
    "Phone number could not be unmuted" : "Telefonski broj nije moguće uključiti",
    "DTMF message could not be sent" : "Nije moguće poslati DTMF poruku",
    "Phone number copied to clipboard" : "Telefonski broj je kopiran u međuspremnik",
    "Phone number could not be copied" : "Telefonski broj nije moguće kopirati",
    "in the lobby" : "u predvorju",
    "Dial out phone" : "Biraj prema van",
    "Hang up phone" : "Prekini poziv",
    "Move back to lobby" : "Vrati u predvorje",
    "Move to conversation" : "Premjesti u razgovor",
    "Dial-in PIN" : "PIN za povezivanje putem telefona",
    "Demote from moderator" : "Ukloni moderatora",
    "Promote to moderator" : "Unaprijedi u moderatora",
    "Resend invitation" : "Ponovno pošalji pozivnicu",
    "Send call notification" : "Pošalji obavijest o pozivu",
    "Dial out phone number" : "Biraj telefonski broj prema van",
    "Resume call for phone number" : "Nastavi poziv za telefonski broj",
    "Put phone number on hold" : "Stavi telefonski broj na čekanje",
    "Unmute phone number" : "Uključi telefonski broj",
    "Mute phone number" : "Utišaj telefonski broj",
    "Copy phone number" : "Kopiraj telefonski broj",
    "Reset custom permissions" : "Poništi prilagođena dopuštenja",
    "Grant all permissions" : "Dodijeli sva dopuštenja",
    "Remove all permissions" : "Ukloni sva dopuštenja",
    "Also ban from this conversation" : "Također zabrani u ovom razgovoru",
    "Internal note (reason to ban)" : "Interna bilješka (razlog zabrane)",
    "Remove" : "Ukloni",
    "Permissions modified for {displayName}" : "Izmijenjena su dopuštenja za {displayName}",
    "Add users, groups or teams" : "Dodaj korisnike, grupe ili timove",
    "Add users or groups" : "Dodaj korisnike ili grupe",
    "Add users or teams" : "Dodaj korisnike ili timove",
    "Add users" : "Dodaj korisnike",
    "Add groups or teams" : "Dodaj grupe ili timove",
    "Add groups" : "Dodaj grupe",
    "Add teams" : "Dodaj timove",
    "Add other sources" : "Dodaj druge izvore",
    "Add emails" : "Dodaj adrese e-pošte",
    "Integrations" : "Integracije",
    "Add federated users" : "Dodaj udružene korisnike",
    "Searching …" : "Traženje…",
    "Search for more users" : "Potraži još korisnika",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Možete pretraživati ili dodati sudionike prema imenu, e-pošti ili udruženom ID-u oblaka",
    "Search or add participants" : "Traži ili dodaj sudionike",
    "Invitation was sent to {actorId}" : "Pozivnica je poslana korisniku {actorId}",
    "An error occurred while adding the participants" : "Došlo je do pogreške pri dodavanju sudionika",
    "A new group conversation with selected participant will be created" : "Stvorit će se novi grupni razgovor s odabranim sudionikom",
    "Participants" : "Sudionici",
    "Pinned by a deleted user" : "Prikvačio obrisani korisnik",
    "Participants ({count})" : "Sudionici ({count})",
    "Open chat" : "Otvori prozor za razmjenu poruka",
    "You have new unread messages in the chat." : "Imate nove nepročitane poruke u prozoru za razmjenu poruka.",
    "You have been mentioned in the chat." : "Spomenuti ste u razmijenjenim porukama.",
    "Search messages" : "Pretraži poruke",
    "Chat" : "Razmjena poruka",
    "Details" : "Pojedinosti",
    "Shared items" : "Dijeljene stavke",
    "Search in {name}" : "Pretraži u {name}",
    "Threads in {name}" : "Niti u {name}",
    "{actor} in {conversation}" : "{actor} u {conversation}",
    "Search messages …" : "Pretraživanje poruka …",
    "Search options" : "Mogućnosti pretraživanja",
    "From User" : "Od korisnika",
    "Since" : "Od",
    "Until" : "Do",
    "No results found" : "Nema rezultata",
    "Load more results" : "Učitaj više rezultata",
    "Recent threads" : "Nedavne niti",
    "Projects" : "Projekti",
    "No shared items" : "Nema dijeljenih stavki",
    "Thread notifications" : "Obavijesti niti",
    "Thread actions" : "Radnje niti",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Poveznica za sudjelovanje u razgovoru",
    "No open conversations found" : "Nisu pronađeni otvoreni razgovori",
    "Either there are no open conversations or you joined all of them." : "Ili nema otvorenih razgovora ili ste se pridružili svima.",
    "Check spelling or use complete words." : "Provjerite pravopis ili upotrijebite cijele riječi.",
    "Search conversations or users" : "Pretraži razgovore ili korisnike",
    "Select conversation" : "Odaberi razgovor",
    "Number length is not valid" : "Duljina broja nije valjana",
    "Region code is not valid" : "Pozivni broj regije nije valjan",
    "Number length is too short" : "Duljina broja je prekratka",
    "Number length is too long" : "Duljina broja je preduga",
    "Number is not valid" : "Broj nije valjan",
    "Phone numbers" : "Telefonski brojevi",
    "Display name: {name}" : "Prikazano ime: {name}",
    "Edit display name" : "Uredi prikazano ime",
    "Display name (required)" : "Prikazano ime (obvezno)",
    "Save name" : "Spremi ime",
    "I picked message bubbles" : "Odabrao sam oblačiće poruka",
    "I picked the list style" : "Odabrao sam stil popisa",
    "Error while setting personal setting" : "Pogreška pri postavljanju osobne postavke",
    "Error while saving sounds setting" : "Pogreška pri spremanju postavke zvukova",
    "Compact conversations list" : "Kompaktni popis razgovora",
    "Chat appearance" : "Izgled chata",
    "Messages list" : "Popis poruka",
    "Message bubbles" : "Oblačići poruka",
    "Play sounds when participants join or leave a call" : "Reproduciraj zvukove kad se sudionici pridruže ili napuste poziv",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "Trenutačno nije dostupno na iPhoneu i iPadu zbog tehničkih ograničenja proizvođača",
    "Notification settings" : "Postavke obavijesti",
    "Sounds for chat and call notifications" : "Zvukovi za obavijesti chata i poziva",
    "Invalid language ({languageId})" : "Neispravan jezik ({languageId})",
    "Default language" : "Zadani jezik",
    "Default language ({languageName})" : "Zadani jezik ({languageName})",
    "Error when trying to load the available live translation languages" : "Pogreška pri učitavanju dostupnih jezika za prijevod uživo",
    "Error when trying to set live translation language" : "Pogreška pri postavljanju jezika prijevoda uživo",
    "Set language used to show the transcriptions" : "Postavi jezik za prikaz pretvorenih tekstova",
    "Select location for attachments" : "Odaberite lokaciju privitaka",
    "Error while setting attachment folder" : "Pogreška pri postavljanju mape za privitke",
    "Error while setting read status privacy" : "Pogreška pri postavljanju privatnosti statusa čitanja",
    "Error while setting typing status privacy" : "Pogreška pri postavljanju privatnosti statusa tipkanja",
    "Error while setting default media state" : "Pogreška pri postavljanju zadanog stanja medija",
    "Turn camera and microphone off by default" : "Zadano isključi kameru i mikrofon",
    "Blur camera background by default" : "Zadano zamuti pozadinu kamere",
    "Skip device preview before joining a call" : "Preskoči pregled uređaja prije pridruživanja pozivu",
    "Appearance & Sounds" : "Izgled i zvukovi",
    "Privacy" : "Privatnost",
    "Send read receipts" : "Šalji potvrde čitanja",
    "When off, all read statuses will be hidden" : "Ako je isključeno, svi statusi čitanja bit će skriveni",
    "Share typing status" : "Dijeli status tipkanja",
    "When off, all typing indicators will be hidden" : "Ako je isključeno, svi indikatori tipkanja bit će skriveni",
    "Attachments folder" : "Mapa s privicima",
    "Toggle full screen" : "Uključi/isključi prikaz preko cijelog zaslona",
    "Return to Home screen" : "Vrati se na početni zaslon",
    "Search" : "Traži",
    "Shortcuts while in a chat" : "Prečaci u chatu",
    "Focus the chat input" : "Fokusirajte ulazne poruke",
    "Unfocus the chat input to use shortcuts" : "Odfokusirajte ulazne poruke kako biste iskoristili prečace",
    "Edit your last message" : "Uredi svoju posljednju poruku",
    "Shortcuts while in a call" : "Prečaci tijekom poziva",
    "Camera on and off" : "Uključi/isključi kameru",
    "Microphone on and off" : "Mikrofon uključen i isključen",
    "Raise or lower hand" : "Podigni ili spusti ruku",
    "Push to talk or push to mute" : "Pritisni za govor ili pritisni za utišavanje",
    "Zoom-in / zoom-out a screen share" : "Povećaj / smanji dijeljenje zaslona",
    "Mouse wheel" : "Kotačić miša",
    "Start call silently" : "Pokreni poziv tiho",
    "Start call" : "Uputi poziv",
    "End call" : "Završi poziv",
    "The server was updated, you cannot start or join a call." : "Poslužitelj je ažuriran, ne možete pokrenuti ni pridružiti se pozivu.",
    "This call has just ended" : "Ovaj je poziv upravo završio",
    "You will be able to join the call only after a moderator starts it." : "Pozivu ćete se moći pridružiti tek nakon što ga moderator pokrene.",
    "End call for everyone" : "Završi poziv za sve",
    "Starting the recording" : "Pokretanje snimanja",
    "Recording" : "Snimanje",
    "The call has been running for one hour." : "Poziv traje već jedan sat.",
    "Cancel recording start" : "Otkaži pokretanje snimanja",
    "Stop recording" : "Zaustavi snimanje",
    "Raise hand" : "Podigni ruku",
    "Raise hand (R)" : "Podigni ruku (R)",
    "Lower hand" : "Spusti ruku",
    "Lower hand (R)" : "Spusti ruku (R)",
    "Send a reaction" : "Pošalji reakciju",
    "React with {reaction}" : "Reagiraj s {reaction}",
    "All tasks done!" : "Svi zadaci su dovršeni!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} od %n zadatka","{done} od %n zadatka","{done} od %n zadataka"],
    "Add participants to this call" : "Dodaj sudionike u ovaj poziv",
    "_%n participant in call_::_%n participants in call_" : ["%n sudionik u pozivu","%n sudionika u pozivu","%n sudionika u pozivu"],
    "Scheduled messages" : "Zakazane poruke",
    "You are not allowed to enable screensharing" : "Nije vam dopušteno omogućiti dijeljenje zaslona",
    "No screensharing" : "Nema dijeljenja zaslona",
    "Screensharing options" : "Mogućnosti dijeljenja zaslona",
    "Enable screensharing" : "Omogući dijeljenje zaslona",
    "Bad sent video and screen quality." : "Nekvalitetan videozapis i prikaz.",
    "Bad sent screen quality." : "Nekvalitetan prikaz.",
    "Bad sent video quality." : "Nekvalitetan videozapis.",
    "Bad sent audio, video and screen quality." : "Nekvalitetan audiozapis, videozapis i prikaz.",
    "Bad sent audio and screen quality." : "Nekvalitetan audiozapis i prikaz.",
    "Bad sent audio and video quality." : "Nekvalitetan audiozapis i videozapis.",
    "Bad sent audio quality." : "Nekvalitetan audiozapis.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Vaša internetska veza ili računalo su opterećeni pa drugi sudionici možda neće moći vidjeti vaš zaslon. Kako biste poboljšali situaciju, pokušajte isključiti zamućenje pozadine ili svoj video tijekom dijeljenja zaslona.",
    "Disable background blur" : "Onemogući zamućenje pozadine",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Vaša internetska veza ili računalo je zauzeto pa drugi sudionici možda neće vidjeti vaš zaslon. Kako biste otklonili poteškoće, pokušajte onemogućiti prijenos videozapisa dok dijelite zaslon.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Vaša internetska veza ili računalo je zauzeto pa drugi sudionici možda neće vidjeti vaš zaslon.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće vidjeti.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće vidjeti i razumjeti. Kako biste otklonili poteškoće, pokušajte onemogućiti zamućenje pozadine ili prijenos videozapisa dok dijelite zaslon.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće vidjeti i razumjeti. Kako biste otklonili poteškoće, pokušajte onemogućiti prijenos videozapisa dok dijelite zaslon.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće vidjeti i razumjeti niti vidjeti vaš zaslon. Kako biste otklonili poteškoće, pokušajte onemogućiti dijeljenje zaslona.",
    "Disable screenshare" : "Onemogući dijeljenje zaslona",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće vidjeti i razumjeti. Kako biste otklonili poteškoće, pokušajte onemogućiti zamućenje pozadine ili prijenos videozapisa.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće vidjeti i razumjeti. Kako biste otklonili poteškoće, pokušajte onemogućiti prijenos videozapisa.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Vaša internetska veza ili računalo je zauzeto pa vas drugi sudionici možda neće razumjeti.",
    "Screen sharing is not supported by your browser." : "Vaš preglednik ne podržava dijeljenje zaslona.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Dijeljenje zaslona zahtijeva učitavanje stranice putem HTTPS-a.",
    "Screensharing requires the page to be loaded through HTTPS." : "Dijeljenje zaslona zahtijeva učitavanje stranice putem HTTPS-a.",
    "An error occurred while starting screensharing." : "Došlo je do pogreške pri pokretanju dijeljenja zaslona.",
    "Select virtual background" : "Odaberite virtualnu pozadinu",
    "Show your screen" : "Pokaži svoj zaslon",
    "Stop screensharing" : "Prekini dijeljenje zaslona",
    "Mute others" : "Utišaj druge",
    "Start recording" : "Započni snimanje",
    "Set up breakout rooms" : "Postavi sobe za odvajanje",
    "Download attendance list" : "Preuzmi popis prisutnosti",
    "Open Calendar" : "Otvori Kalendar",
    "Remove participant {name}" : "Ukloni sudionika {name}",
    "Would you like to delete this conversation?" : "Želite li izbrisati ovaj razgovor?",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["Ovaj će razgovor biti automatski izbrisan za sve nakon %n dan neaktivnosti.","Ovaj će razgovor biti automatski izbrisan za sve nakon %n dana neaktivnosti.","Ovaj će razgovor biti automatski izbrisan za sve nakon %n dana neaktivnosti."],
    "Are you sure you want to delete this conversation?" : "Jeste li sigurni da želite izbrisati ovaj razgovor?",
    "Delete now" : "Izbriši odmah",
    "Keep" : "Zadrži",
    "Open dialpad" : "Otvori tipkovnicu za biranje",
    "Select a region" : "Odaberite regiju",
    "Local time: {time}" : "Lokalno vrijeme: {time}",
    "Scheduled {datetime}" : "Zakazano {datetime}",
    "Scheduled for {datetime}" : "Zakazano za {datetime}",
    "Search …" : "Traži …",
    "Message without mention" : "Poruka bez spominjanja",
    "Mention myself" : "Spomeni sebe",
    "Mention everyone" : "Spomeni sve",
    "Select a conversation" : "Odaberite razgovor",
    "Select a mode" : "Odaberite način",
    "You do not have permissions to access this conversation." : "Nemate dopuštenja za pristup ovom razgovoru.",
    "Join a different conversation or start a new one." : "Pridružite se drugom razgovoru ili pokrenite novi.",
    "The conversation does not exist" : "Razgovor ne postoji",
    "Join a conversation or start a new one!" : "Pridružite se razgovoru ili započnite novi!",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "Ovaj razgovor je otvoren u drugoj kartici. Trenutna verzija poslužitelja ne podržava otvaranje razgovora u više kartica.",
    "Creating and joining a conversation with \"{userid}\"" : "Stvaranje i pridruživanje razgovoru s \"{userid}\"",
    "Join a conversation or start a new one" : "Pridružite se razgovoru ili započnite novi",
    "Error while joining the conversation" : "Pogreška pri pridruživanju razgovoru",
    "Another user" : "Drugi korisnik",
    "Hey! Are you using the list style or message bubbles?" : "Hej! Koristite li prikaz u obliku popisa ili oblačiće poruka?",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Nextcloud korisnik",
    "User password" : "Korisnička lozinka",
    "Talk conversation" : "Razgovori u alatu Talk",
    "Skip TLS verification" : "Preskoči TLS provjeru",
    "Matrix server URL" : "URL poslužitelja Matrix",
    "User" : "Korisnik",
    "Matrix channel" : "Matrix kanal",
    "Mattermost server URL" : "URL poslužitelja Mattermost",
    "Mattermost user" : "Mattermost korisnik",
    "Team name" : "Naziv tima",
    "Channel name" : "Naziv kanala",
    "Rocket.Chat server URL" : "URL poslužitelja Rocket.Chat",
    "User name or email address" : "Korisničko ime ili adresa e-pošte",
    "Rocket.Chat channel" : "Rocket.Chat kanal",
    "Zulip server URL" : "URL poslužitelja Zulip",
    "Bot user name" : "Korisničko ime Bota",
    "Bot API key" : "Ključ API-ja Bot",
    "Zulip channel" : "Zulip kanal",
    "API token" : "API token",
    "Slack channel" : "Slack kanal",
    "Server ID or name" : "ID ili naziv poslužitelja",
    "Channel ID (prefixed with \"ID:\") or name" : "ID kanala (s prefiksom \"ID:\") ili naziv",
    "Channel" : "Kanal",
    "Login" : "Prijava",
    "Chat ID" : "ID alata za razmjenu poruka",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL IRC poslužitelja (npr. chat.freenode.net:6667)",
    "Nickname" : "Nadimak",
    "Connection password" : "Lozinka veze",
    "IRC channel" : "IRC kanal",
    "Channel password" : "Lozinka za kanal",
    "NickServ nickname" : "NickServ nadimak",
    "NickServ password" : "NickServ lozinka",
    "Use TLS" : "Koristi TLS",
    "Use SASL" : "Koristi SASL",
    "Tenant ID" : "ID stanara",
    "Client ID" : "ID klijenta",
    "Team ID" : "ID tima",
    "Thread ID" : "ID dretve",
    "XMPP/Jabber server URL" : "URL poslužitelja XMPP/Jabber",
    "MUC server URL" : "URL poslužitelja MUC",
    "Jabber ID" : "ID Jabbera",
    "Pinned messages" : "Prikvačene poruke",
    "Media" : "Medij",
    "Polls" : "Ankete",
    "Deck cards" : "Deck kartice",
    "Voice messages" : "Glasovne poruke",
    "Locations" : "Lokacije",
    "Call recordings" : "Snimke poziva",
    "Audio" : "Audio",
    "Show all pinned messages" : "Prikaži sve prikvačene poruke",
    "Show all media" : "Prikaži sve medijske datoteke",
    "Show all files" : "Prikaži sve datoteke",
    "Show all polls" : "Prikaži sve ankete",
    "Show all deck cards" : "Prikaži sve Deck kartice",
    "Show all voice messages" : "Prikaži sve glasovne poruke",
    "Show all locations" : "Prikaži sve lokacije",
    "Show all call recordings" : "Prikaži sve snimke poziva",
    "Show all audio" : "Prikaži sve zvukove",
    "Show all other" : "Prikaži sve ostalo",
    "Follow conversation settings" : "Slijedi postavke razgovora",
    "Group" : "Grupa",
    "Team" : "Tim",
    "You reconnected to the call" : "Ponovno ste se povezali na poziv",
    "{actor} reconnected to the call" : "{actor} se ponovno povezao na poziv",
    "You added {user0} and {user1}" : "Dodali ste {user0} i {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Dodali ste {user0}, {user1} i još %n sudionika","Dodali ste {user0}, {user1} i još %n sudionika","Dodali ste {user0}, {user1} i još %n sudionika"],
    "An administrator added you and {user0}" : "Administrator je dodao vas i {user0}",
    "{actor} added you and {user0}" : "{actor} je dodao vas i {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Administrator je dodao vas, {user0} i još %n sudionika","Administrator je dodao vas, {user0} i još %n sudionika","Administrator je dodao vas, {user0} i još %n sudionika"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} je dodao vas, {user0} i još %n sudionika","{actor} je dodao vas, {user0} i još %n sudionika","{actor} je dodao vas, {user0} i još %n sudionika"],
    "An administrator added {user0} and {user1}" : "Administrator je dodao {user0} i {user1}",
    "{actor} added {user0} and {user1}" : "{actor} je dodao {user0} i {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Administrator je dodao {user0}, {user1} i još %n sudionika","Administrator je dodao {user0}, {user1} i još %n sudionika","Administrator je dodao {user0}, {user1} i još %n sudionika"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} je dodao {user0}, {user1} i još %n sudionika","{actor} je dodao {user0}, {user1} i još %n sudionika","{actor} je dodao {user0}, {user1} i još %n sudionika"],
    "You removed {user0} and {user1}" : "Uklonili ste {user0} i {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Uklonili ste {user0}, {user1} i još %n sudionika","Uklonili ste {user0}, {user1} i još %n sudionika","Uklonili ste {user0}, {user1} i još %n sudionika"],
    "An administrator removed you and {user0}" : "Administrator je uklonio vas i {user0}",
    "{actor} removed you and {user0}" : "{actor} je uklonio vas i {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Administrator je uklonio vas, {user0} i još %n sudionika","Administrator je uklonio vas, {user0} i još %n sudionika","Administrator je uklonio vas, {user0} i još %n sudionika"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} je uklonio vas, {user0} i još %n sudionika","{actor} je uklonio vas, {user0} i još %n sudionika","{actor} je uklonio vas, {user0} i još %n sudionika"],
    "An administrator removed {user0} and {user1}" : "Administrator je uklonio {user0} i {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} je uklonio {user0} i {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Administrator je uklonio {user0}, {user1} i još %n sudionika","Administrator je uklonio {user0}, {user1} i još %n sudionika","Administrator je uklonio {user0}, {user1} i još %n sudionika"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} je uklonio {user0}, {user1} i još %n sudionika","{actor} je uklonio {user0}, {user1} i još %n sudionika","{actor} je uklonio {user0}, {user1} i još %n sudionika"],
    "You and {user0} joined the call" : "Vi i {user0} pridružili ste se pozivu",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Vi, {user0} i još %n sudionik pridružili ste se pozivu","Vi, {user0} i još %n sudionika pridružili ste se pozivu","Vi, {user0} i još %n sudionika pridružili ste se pozivu"],
    "{user0} and {user1} joined the call" : "{user0} i {user1} pridružili su se pozivu",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} i još %n sudionik pridružili su se pozivu","{user0}, {user1} i još %n sudionika pridružili su se pozivu","{user0}, {user1} i još %n sudionika pridružili su se pozivu"],
    "You and {user0} left the call" : "Vi i {user0} napustili ste poziv",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Vi, {user0} i još %n sudionik napustili ste poziv","Vi, {user0} i još %n sudionika napustili ste poziv","Vi, {user0} i još %n sudionika napustili ste poziv"],
    "{user0} and {user1} left the call" : "{user0} i {user1} napustili su poziv",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} i još %n sudionik napustili su poziv","{user0}, {user1} i još %n sudionika napustili su poziv","{user0}, {user1} i još %n sudionika napustili su poziv"],
    "You promoted {user0} and {user1} to moderators" : "Postavili ste {user0} i {user1} za moderatore",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Postavili ste {user0}, {user1} i još %n sudionika za moderatore","Postavili ste {user0}, {user1} i još %n sudionika za moderatore","Postavili ste {user0}, {user1} i još %n sudionika za moderatore"],
    "An administrator promoted you and {user0} to moderators" : "Administrator je postavio vas i {user0} za moderatore",
    "{actor} promoted you and {user0} to moderators" : "{actor} je postavio vas i {user0} za moderatore",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Administrator je postavio vas, {user0} i još %n sudionika za moderatore","Administrator je postavio vas, {user0} i još %n sudionika za moderatore","Administrator je postavio vas, {user0} i još %n sudionika za moderatore"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} je postavio vas, {user0} i još %n sudionika za moderatore","{actor} je postavio vas, {user0} i još %n sudionika za moderatore","{actor} je postavio vas, {user0} i još %n sudionika za moderatore"],
    "An administrator promoted {user0} and {user1} to moderators" : "Administrator je postavio {user0} i {user1} za moderatore",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} je postavio {user0} i {user1} za moderatore",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Administrator je postavio {user0}, {user1} i još %n sudionika za moderatore","Administrator je postavio {user0}, {user1} i još %n sudionika za moderatore","Administrator je postavio {user0}, {user1} i još %n sudionika za moderatore"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} je postavio {user0}, {user1} i još %n sudionika za moderatore","{actor} je postavio {user0}, {user1} i još %n sudionika za moderatore","{actor} je postavio {user0}, {user1} i još %n sudionika za moderatore"],
    "You demoted {user0} and {user1} from moderators" : "Uklonili ste {user0} i {user1} s uloge moderatora",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Uklonili ste {user0}, {user1} i još %n sudionika s uloge moderatora","Uklonili ste {user0}, {user1} i još %n sudionika s uloge moderatora","Uklonili ste {user0}, {user1} i još %n sudionika s uloge moderatora"],
    "An administrator demoted you and {user0} from moderators" : "Administrator je uklonio vas i {user0} s uloge moderatora",
    "{actor} demoted you and {user0} from moderators" : "{actor} je uklonio vas i {user0} s uloge moderatora",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Administrator je uklonio vas, {user0} i još %n sudionika s uloge moderatora","Administrator je uklonio vas, {user0} i još %n sudionika s uloge moderatora","Administrator je uklonio vas, {user0} i još %n sudionika s uloge moderatora"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} je uklonio vas, {user0} i još %n sudionika s uloge moderatora","{actor} je uklonio vas, {user0} i još %n sudionika s uloge moderatora","{actor} je uklonio vas, {user0} i još %n sudionika s uloge moderatora"],
    "An administrator demoted {user0} and {user1} from moderators" : "Administrator je uklonio {user0} i {user1} s uloge moderatora",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} je uklonio {user0} i {user1} s uloge moderatora",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Administrator je uklonio {user0}, {user1} i još %n sudionika s uloge moderatora","Administrator je uklonio {user0}, {user1} i još %n sudionika s uloge moderatora","Administrator je uklonio {user0}, {user1} i još %n sudionika s uloge moderatora"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} je uklonio {user0}, {user1} i još %n sudionika s uloge moderatora","{actor} je uklonio {user0}, {user1} i još %n sudionika s uloge moderatora","{actor} je uklonio {user0}, {user1} i još %n sudionika s uloge moderatora"],
    "You:" : "Vi:",
    "You: {lastMessage}" : "Vi: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The server was updated." : "Poslužitelj je ažuriran.",
    "(edited by you)" : "(uredili ste vi)",
    "(edited by a deleted user)" : "(uredio obrisani korisnik)",
    "(edited by {moderator})" : "(uredio {moderator})",
    "The recording failed. Please contact your administrator." : "Snimanje nije uspjelo. Obratite se administratoru.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Pokušavate se pridružiti razgovoru dok imate otvorenu sesiju u drugom prozoru ili na drugom uređaju. Nextcloud Talk trenutačno ne podržava tu radnju. Što želite učiniti?",
    "Leave this page" : "Napusti ovu stranicu",
    "Join here" : "Pridruži se ovdje",
    "Deck card has been posted to {conversation}" : "Deck kartica je objavljena u {conversation}",
    "An error occurred while posting deck card to conversation" : "Došlo je do pogreške pri objavi Deck kartice u razgovor",
    "Post to a conversation" : "Objavite u razgovoru",
    "Post to conversation" : "Objavi u razgovoru",
    "Location has been posted to {conversation}" : "Lokacija je objavljena u {conversation}",
    "An error occurred while posting location to conversation" : "Došlo je do pogreške pri objavi lokacije u razgovor",
    "Share to a conversation" : "Podijeli u razgovor",
    "Share to conversation" : "Podijeli u razgovor",
    "In conversation" : "U razgovoru",
    "Search in conversation: {conversation}" : "Pretraži u razgovoru: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Vaši su zahtjevi trenutačno ograničeni zbog zaštite od brute force napada",
    "Error while clearing conversation history" : "Pogreška pri brisanju povijesti razgovora",
    "Error occurred while allowing guests" : "Došlo je do pogreške pri omogućavanju pristupa gostima",
    "Error occurred while disallowing guests" : "Došlo je do pogreške pri onemogućavanju pristupa gostima",
    "Error occurred when restricting the conversation to moderator" : "Došlo je do pogreške pri ograničavanju razgovora samo na moderatore",
    "Error occurred when opening the conversation to everyone" : "Došlo je do pogreške pri otvaranju razgovora svima",
    "Conversation password has been saved" : "Zaporka razgovora je spremljena",
    "Conversation password has been removed" : "Zaporka razgovora je uklonjena",
    "Error occurred while saving conversation password" : "Došlo je do pogreške pri spremanju zaporke razgovora",
    "Call recording is starting." : "Snimanje poziva započinje.",
    "Call recording stopped while starting." : "Snimanje poziva je zaustavljeno tijekom pokretanja.",
    "Call recording stopped. You will be notified once the recording is available." : "Snimanje poziva je zaustavljeno. Bit ćete obaviješteni kada snimka bude dostupna.",
    "Conversation picture set" : "Slika razgovora je postavljena",
    "Conversation picture deleted" : "Slika razgovora je obrisana",
    "Could not delete the conversation picture" : "Nije moguće obrisati sliku razgovora",
    "Could not remove the automatic expiration" : "Nije moguće ukloniti automatsko istjecanje",
    "Could not post message: {errorMessage}" : "Nije moguće objaviti poruku: {errorMessage}",
    "Participant is banned successfully" : "Sudionik je uspješno zabranjen",
    "Error while banning the participant" : "Pogreška pri zabrani sudionika",
    "An error occurred while fetching the participants" : "Došlo je do pogreške pri dohvaćanju sudionika",
    "Could not send invitation to {actorId}" : "Nije moguće poslati pozivnicu za {actorId}",
    "Invitations sent" : "Pozivnice su poslane",
    "Error occurred when sending invitations" : "Došlo je do pogreške pri slanju pozivnica",
    "Failed to join the conversation." : "Nije se uspjelo pridružiti razgovoru.",
    "An error occurred while creating breakout rooms" : "Došlo je do pogreške pri stvaranju soba za odvajanje",
    "An error occurred while re-ordering the attendees" : "Došlo je do pogreške pri promjeni redoslijeda sudionika",
    "An error occurred while deleting breakout rooms" : "Došlo je do pogreške pri brisanju soba za odvajanje",
    "An error occurred while starting breakout rooms" : "Došlo je do pogreške pri pokretanju soba za odvajanje",
    "An error occurred while stopping breakout rooms" : "Došlo je do pogreške pri zaustavljanju soba za odvajanje",
    "An error occurred while sending a message to the breakout rooms" : "Došlo je do pogreške pri slanju poruke u sobe za odvajanje",
    "An error occurred while requesting assistance" : "Došlo je do pogreške pri traženju pomoći",
    "An error occurred while resetting the request for assistance" : "Došlo je do pogreške pri poništavanju zahtjeva za pomoć",
    "An error occurred while joining breakout room" : "Došlo je do pogreške pri pridruživanju sobi za odvajanje",
    "Failed to rename the thread" : "Nije uspjelo preimenovati nit",
    "Error fetching upcoming events" : "Pogreška pri dohvaćanju nadolazećih događaja",
    "Error fetching upcoming reminders" : "Pogreška pri dohvaćanju nadolazećih podsjetnika",
    "An error occurred while accepting an invitation" : "Došlo je do pogreške pri prihvaćanju pozivnice",
    "An error occurred while rejecting an invitation" : "Došlo je do pogreške pri odbijanju pozivnice",
    "{guest} (guest)" : "{guest} (gost)",
    "Poll draft has been saved" : "Skica ankete je spremljena",
    "An error occurred while saving the draft" : "Došlo je do pogreške pri spremanju skice",
    "An error occurred while submitting your vote" : "Došlo je do pogreške pri slanju vašeg glasa",
    "An error occurred while ending the poll" : "Došlo je do pogreške pri završavanju ankete",
    "An error occurred while deleting the poll draft" : "Došlo je do pogreške pri brisanju skice ankete",
    "Poll \"{name}\" was created by {user}. Click to vote" : "Anketu \"{name}\" stvorio je {user}. Kliknite za glasanje",
    "Failed to add reaction" : "Nije uspjelo dodati reakciju",
    "Failed to remove reaction" : "Nije uspjelo ukloniti reakciju",
    "The server is in maintenance mode." : "Poslužitelj je u načinu održavanja.",
    "Federated server was updated." : "Udruženi poslužitelj je ažuriran.",
    "Error while uploading file \"{fileName}\"" : "Pogreška pri otpremanju datoteke „{fileName}”",
    "Not enough free space to upload file \"{fileName}\"" : "Nema dovoljno slobodnog prostora za otpremanje datoteke „{fileName}”",
    "You are not allowed to share files" : "Nije vam dopušteno dijeliti datoteke",
    "Error while sharing file" : "Pogreška pri dijeljenju datoteke",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Nextcloud Talk ne podržava trenutni preglednik. Preuzmite najnoviju inačicu preglednika Mozilla Firefox, Microsoft Edge, Google Chrome, Opera ili Apple Safari.",
    "_%n hour_::_%n hours_" : ["%n sat","%n sata","%n sati"],
    "_%n day_::_%n days_" : ["%n dan","%n dana","%n dana"],
    "_%n week_::_%n weeks_" : ["%n tjedan","%n tjedna","%n tjedana"],
    "_In %n hour_::_In %n hours_" : ["Za %n sat","Za %n sata","Za %n sati"],
    "_%n minute _::_%n minutes_" : ["%n minuta","%n minute","%n minuta"],
    "In {hours} and {minutes}" : "Za {hours} i {minutes}",
    "_In %n minute_::_In %n minutes_" : ["Za %n minutu","Za %n minute","Za %n minuta"],
    "Later today – {timeLocale}" : "Kasnije danas – {timeLocale}",
    "Set time for later today" : "Postavi vrijeme za kasnije danas",
    "Tomorrow – {timeLocale}" : "Sutra – {timeLocale}",
    "Set time for tomorrow" : "Postavi vrijeme za sutra",
    "This weekend – {timeLocale}" : "Ovaj vikend – {timeLocale}",
    "Set time for this weekend" : "Postavi vrijeme za ovaj vikend",
    "Next week – {timeLocale}" : "Sljedeći tjedan – {timeLocale}",
    "Set time for next week" : "Postavi vrijeme za sljedeći tjedan",
    "Message link copied to clipboard" : "Poveznica iz poruke kopirana je u međuspremnik",
    "Conversation link copied to clipboard" : "Poveznica razgovora kopirana je u međuspremnik",
    "The link could not be copied" : "Poveznicu nije moguće kopirati",
    "Error while parsing a PROPFIND error" : "Pogreška pri obradi PROPFIND pogreške",
    "Sending signaling message has failed" : "Slanje signalne poruke nije uspjelo",
    "Lost connection to signaling server. Trying to reconnect." : "Veza sa signalnim poslužiteljem je prekinuta. Pokušavam se ponovno povezati.",
    "Lost connection to signaling server." : "Izgubljena je veza sa signalnim poslužiteljem.",
    "Connecting is taking longer than expected …" : "Povezivanje traje dulje nego što se očekivalo …",
    "Failed to connect. Retrying …" : "Povezivanje nije uspjelo. Pokušavam ponovno …",
    "Failed to connect. The signaling server may be set up incorrectly" : "Povezivanje nije uspjelo. Signalni poslužitelj možda je pogrešno postavljen",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Konfigurirani signalni poslužitelj mora se ažurirati kako bi bio kompatibilan s ovom verzijom Talka. Obratite se administraciji.",
    "Please restart the app." : "Ponovno pokrenite aplikaciju.",
    "Please reload the page." : "Ponovno učitajte stranicu.",
    "Please try to restart the app." : "Pokušajte ponovno pokrenuti aplikaciju.",
    "Please try to reload the page." : "Pokušajte ponovno učitati stranicu.",
    "Do not disturb" : "Ne ometaj",
    "Away" : "Odsutan",
    "Microphone {number}" : "Mikrofon {number}",
    "Camera {number}" : "Kamera {number}",
    "Speaker {number}" : "Zvučnik {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Pričate dok je utišan zvuk, isključite utišavanje zvuka kako bi vas čuli drugi sudionici razgovora",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Nije uspostavljena veza s najmanje jednim sudionikom. Vjerojatno vam je potreban poslužitelj TURN. Obratite se svom administratoru i zatražite da omogući korištenje poslužitelja TURN u skladu s {linkstart}ovom dokumentacijom{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Radnja traje duže od očekivanog. Jesu li postavljena (ili odbijena) dopuštenja za pristupanje medijima? Ako jesu, ponovno pokrenite preglednik jer nema prijenosa zvuka i videosignala",
    "Access to microphone & camera is only possible with HTTPS" : "Pristup mikrofonu i kameri moguć je samo putem HTTPS-a",
    "Please move your setup to HTTPS" : "Prebacite postavku na HTTPS",
    "Access to microphone & camera was denied" : "Pristup mikrofonu i kameri je odbijen",
    "WebRTC is not supported in your browser" : "Vaš preglednik ne podržava WebRTC",
    "Please use a different browser like Firefox or Chrome" : "Koristite se drugim preglednikom kao što je Firefox ili Chrome",
    "Error while accessing microphone & camera" : "Došlo je do pogreške pri pristupanju mikrofonu i kameri",
    "%s Talk on your mobile devices" : "%s aplikacija Talk na vašim mobilnim uređajima",
    "Join conversations at any time, anywhere, on any device." : "Pridružite se razgovorima u bilo koje vrijeme, bilo gdje, na bilo kojem uređaju.",
    "Android app" : "Aplikacija za Android",
    "iOS app" : "Aplikacija za iOS",
    "__language_name__" : "Hrvatski",
    "Webhook Demo" : "Demo webhooka",
    "Call summary (%s)" : "Sažetak poziva (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Bot za sažetak poziva objavljuje poruku s pregledom nakon poziva, navodi sve sudionike i ističe zadatke",
    "Tasks" : "Zadaci",
    "Notes" : "Bilješke",
    "Reports" : "Izvješća",
    "Decisions" : "Odluke",
    "Agenda" : "Dnevni red",
    "Call summary" : "Sažetak poziva",
    "Call summary - {title}" : "Sažetak poziva – {title}",
    "Talk to %s" : "Razgovarajte s %s",
    "Talk conversation for event" : "Talk razgovor za događaj",
    "Client Push is installed, this improves the performance of desktop clients." : "Client Push je instaliran, što poboljšava performanse desktop klijenata.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} nije instaliran, to može dovesti do problema s performansama pri korištenju desktop klijenata.",
    "Next meeting" : "Sljedeći sastanak",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Zakažite sastanak iz svojeg kalendara. Talk razgovor mora biti postavljen kao lokacija da bi se ovdje prikazao",
    "Join conversations from remote Nextcloud servers" : "Pridruži se razgovorima s udaljenih Nextcloud poslužitelja",
    "Your default media state has been saved" : "Vaše zadano stanje medija je spremljeno",
    "Set reminder for later today" : "Postavi podsjetnik za kasnije danas",
    "Set reminder for tomorrow" : "Postavi podsjetnik za sutra",
    "Set reminder for this weekend" : "Postavi podsjetnik za ovaj vikend",
    "Set reminder for next week" : "Postavi podsjetnik na sljedeći tjedan",
    "Generate summary" : "Generiraj sažetak",
    "Open poll • You voted already" : "Otvorena anketa • Već ste glasali",
    "Open poll • Click to vote" : "Otvorena anketa • Kliknite za glasanje",
    "Poll • Ended" : "Anketa • Završena",
    "Talk recording from {time} ({conversation})" : "Snimak iz aplikacije Talk od {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Rezultati ankete • %n glas","Rezultati ankete • %n glasa","Rezultati ankete • %n glasova"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Otvorena anketa • %n glas","Otvorena anketa • %n glasa","Otvorena anketa • %n glasova"],
    "Submit vote" : "Pošalji glas",
    "Your privacy setting has been saved" : "Postavka privatnosti je spremljena",
    "Your personal setting has been saved" : "Vaša osobna postavka je spremljena",
    "Failed to save sounds setting" : "Spremanje postavki zvukova nije uspjelo",
    "Sounds setting saved" : "Postavka zvukova je spremljena",
    "Always shown if recording consent is required" : "Uvijek se prikazuje ako je potrebna privola za snimanje",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud Talk je ažuriran; ne možete pokrenuti ni pridružiti se pozivu.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Pridružili ste se razgovoru u drugom prozoru ili na drugom uređaju. Nextcloud Talk trenutačno ne podržava tu radnju pa je ova sesija zatvorena.",
    "Nextcloud Talk was updated." : "Nextcloud Talk je ažuriran.",
    "Nextcloud is in maintenance mode." : "Nextcloud je u načinu održavanja.",
    "Nextcloud Talk Federation was updated." : "Nextcloud Talk udruženje je ažurirano.",
    "Enable live translation" : "Omogući prijevod uživo",
    "I picked list style" : "Odabrao sam stil popisa",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Hej! Koristite li Talk u prikazu popisa ili s oblačićima poruka?"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
